# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/RL_OM',
                'doc_host': 'https://majoma7.github.io',
                'git_url': 'https://github.com/majoma7/RL_OM',
                'lib_path': 'RL_OM'},
  'syms': { 'RL_OM.agents.benchmark_agents.PPO_SB3': { 'RL_OM.agents.benchmark_agents.PPO_SB3.PPOAgent': ( 'agents/benchmark_agents/temp_ppo_sb3.html#ppoagent',
                                                                                                           'RL_OM/agents/benchmark_agents/PPO_SB3.py'),
                                                       'RL_OM.agents.benchmark_agents.PPO_SB3.PPOAgent.__init__': ( 'agents/benchmark_agents/temp_ppo_sb3.html#ppoagent.__init__',
                                                                                                                    'RL_OM/agents/benchmark_agents/PPO_SB3.py'),
                                                       'RL_OM.agents.benchmark_agents.PPO_SB3.PPOAgent.fit': ( 'agents/benchmark_agents/temp_ppo_sb3.html#ppoagent.fit',
                                                                                                               'RL_OM/agents/benchmark_agents/PPO_SB3.py'),
                                                       'RL_OM.agents.benchmark_agents.PPO_SB3.PPOPolicy': ( 'agents/benchmark_agents/temp_ppo_sb3.html#ppopolicy',
                                                                                                            'RL_OM/agents/benchmark_agents/PPO_SB3.py'),
                                                       'RL_OM.agents.benchmark_agents.PPO_SB3.PPOPolicy.draw_action': ( 'agents/benchmark_agents/temp_ppo_sb3.html#ppopolicy.draw_action',
                                                                                                                        'RL_OM/agents/benchmark_agents/PPO_SB3.py'),
                                                       'RL_OM.agents.benchmark_agents.PPO_SB3.PPOPolicy.reset': ( 'agents/benchmark_agents/temp_ppo_sb3.html#ppopolicy.reset',
                                                                                                                  'RL_OM/agents/benchmark_agents/PPO_SB3.py')},
            'RL_OM.agents.benchmark_agents.PPO_TEMP': {},
            'RL_OM.agents.benchmark_agents.cbs': { 'RL_OM.agents.benchmark_agents.cbs.CBSAgent': ( 'agents/benchmark_agents/capped_base_stock.html#cbsagent',
                                                                                                   'RL_OM/agents/benchmark_agents/cbs.py'),
                                                   'RL_OM.agents.benchmark_agents.cbs.CBSAgent.__init__': ( 'agents/benchmark_agents/capped_base_stock.html#cbsagent.__init__',
                                                                                                            'RL_OM/agents/benchmark_agents/cbs.py'),
                                                   'RL_OM.agents.benchmark_agents.cbs.CBSAgent.fit': ( 'agents/benchmark_agents/capped_base_stock.html#cbsagent.fit',
                                                                                                       'RL_OM/agents/benchmark_agents/cbs.py'),
                                                   'RL_OM.agents.benchmark_agents.cbs.CBSPolicy': ( 'agents/benchmark_agents/capped_base_stock.html#cbspolicy',
                                                                                                    'RL_OM/agents/benchmark_agents/cbs.py'),
                                                   'RL_OM.agents.benchmark_agents.cbs.CBSPolicy.__init__': ( 'agents/benchmark_agents/capped_base_stock.html#cbspolicy.__init__',
                                                                                                             'RL_OM/agents/benchmark_agents/cbs.py'),
                                                   'RL_OM.agents.benchmark_agents.cbs.CBSPolicy.calculate_grid': ( 'agents/benchmark_agents/capped_base_stock.html#cbspolicy.calculate_grid',
                                                                                                                   'RL_OM/agents/benchmark_agents/cbs.py'),
                                                   'RL_OM.agents.benchmark_agents.cbs.CBSPolicy.draw_action': ( 'agents/benchmark_agents/capped_base_stock.html#cbspolicy.draw_action',
                                                                                                                'RL_OM/agents/benchmark_agents/cbs.py'),
                                                   'RL_OM.agents.benchmark_agents.cbs.CBSPolicy.draw_action_train': ( 'agents/benchmark_agents/capped_base_stock.html#cbspolicy.draw_action_train',
                                                                                                                      'RL_OM/agents/benchmark_agents/cbs.py'),
                                                   'RL_OM.agents.benchmark_agents.cbs.CBSPolicy.reset': ( 'agents/benchmark_agents/capped_base_stock.html#cbspolicy.reset',
                                                                                                          'RL_OM/agents/benchmark_agents/cbs.py'),
                                                   'RL_OM.agents.benchmark_agents.cbs.CBSPolicy.run_simulation': ( 'agents/benchmark_agents/capped_base_stock.html#cbspolicy.run_simulation',
                                                                                                                   'RL_OM/agents/benchmark_agents/cbs.py'),
                                                   'RL_OM.agents.benchmark_agents.cbs.CBSPolicy.set_params': ( 'agents/benchmark_agents/capped_base_stock.html#cbspolicy.set_params',
                                                                                                               'RL_OM/agents/benchmark_agents/cbs.py')},
            'RL_OM.agents.benchmark_agents.eoq': { 'RL_OM.agents.benchmark_agents.eoq.EOQAgent': ( 'agents/benchmark_agents/eoq.html#eoqagent',
                                                                                                   'RL_OM/agents/benchmark_agents/eoq.py'),
                                                   'RL_OM.agents.benchmark_agents.eoq.EOQAgent.__init__': ( 'agents/benchmark_agents/eoq.html#eoqagent.__init__',
                                                                                                            'RL_OM/agents/benchmark_agents/eoq.py'),
                                                   'RL_OM.agents.benchmark_agents.eoq.EOQAgent.fit': ( 'agents/benchmark_agents/eoq.html#eoqagent.fit',
                                                                                                       'RL_OM/agents/benchmark_agents/eoq.py'),
                                                   'RL_OM.agents.benchmark_agents.eoq.EOQPolicy': ( 'agents/benchmark_agents/eoq.html#eoqpolicy',
                                                                                                    'RL_OM/agents/benchmark_agents/eoq.py'),
                                                   'RL_OM.agents.benchmark_agents.eoq.EOQPolicy.__init__': ( 'agents/benchmark_agents/eoq.html#eoqpolicy.__init__',
                                                                                                             'RL_OM/agents/benchmark_agents/eoq.py'),
                                                   'RL_OM.agents.benchmark_agents.eoq.EOQPolicy.draw_action': ( 'agents/benchmark_agents/eoq.html#eoqpolicy.draw_action',
                                                                                                                'RL_OM/agents/benchmark_agents/eoq.py'),
                                                   'RL_OM.agents.benchmark_agents.eoq.EOQPolicy.reset': ( 'agents/benchmark_agents/eoq.html#eoqpolicy.reset',
                                                                                                          'RL_OM/agents/benchmark_agents/eoq.py'),
                                                   'RL_OM.agents.benchmark_agents.eoq.EOQPolicy.set_q_star': ( 'agents/benchmark_agents/eoq.html#eoqpolicy.set_q_star',
                                                                                                               'RL_OM/agents/benchmark_agents/eoq.py')},
            'RL_OM.agents.benchmark_agents.mp_agents_ERM': { 'RL_OM.agents.benchmark_agents.mp_agents_ERM.FakePolicy': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#fakepolicy',
                                                                                                                         'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.FakePolicy.reset': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#fakepolicy.reset',
                                                                                                                               'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.LERMsgdAgent_MP': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#lermsgdagent_mp',
                                                                                                                              'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.LERMsgdAgent_MP.__init__': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#lermsgdagent_mp.__init__',
                                                                                                                                       'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.LERMsgdAgent_MP.draw_action': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#lermsgdagent_mp.draw_action',
                                                                                                                                          'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.LERMsgdAgent_MP.fit_epoch': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#lermsgdagent_mp.fit_epoch',
                                                                                                                                        'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.LinearModel': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#linearmodel',
                                                                                                                          'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.LinearModel.__init__': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#linearmodel.__init__',
                                                                                                                                   'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.LinearModel.forward': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#linearmodel.forward',
                                                                                                                                  'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.MLP': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#mlp',
                                                                                                                  'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.MLP.__init__': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#mlp.__init__',
                                                                                                                           'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.MLP.forward': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#mlp.forward',
                                                                                                                          'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.MLPsgdAgent': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#mlpsgdagent',
                                                                                                                          'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.MLPsgdAgent.__init__': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#mlpsgdagent.__init__',
                                                                                                                                   'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.MLPsgdAgent.draw_action': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#mlpsgdagent.draw_action',
                                                                                                                                      'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.MLPsgdAgent.fit_epoch': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#mlpsgdagent.fit_epoch',
                                                                                                                                    'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.NewsvendorData': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#newsvendordata',
                                                                                                                             'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.NewsvendorData.__getitem__': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#newsvendordata.__getitem__',
                                                                                                                                         'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.NewsvendorData.__init__': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#newsvendordata.__init__',
                                                                                                                                      'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.NewsvendorData.__len__': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#newsvendordata.__len__',
                                                                                                                                     'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.SGDBase': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#sgdbase',
                                                                                                                      'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.SGDBase.__init__': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#sgdbase.__init__',
                                                                                                                               'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.SGDBase.eval': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#sgdbase.eval',
                                                                                                                           'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.SGDBase.fit': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#sgdbase.fit',
                                                                                                                          'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.SGDBase.max_or_zero': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#sgdbase.max_or_zero',
                                                                                                                                  'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.SGDBase.pinball_loss': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#sgdbase.pinball_loss',
                                                                                                                                   'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.SGDBase.predict': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#sgdbase.predict',
                                                                                                                              'RL_OM/agents/benchmark_agents/mp_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.mp_agents_ERM.SGDBase.train': ( 'agents/benchmark_agents/erm_agents_multi_period_heuristic.html#sgdbase.train',
                                                                                                                            'RL_OM/agents/benchmark_agents/mp_agents_ERM.py')},
            'RL_OM.agents.benchmark_agents.nv_agents': { 'RL_OM.agents.benchmark_agents.nv_agents.FakePolicy': ( 'agents/benchmark_agents/basic_nv_agents.html#fakepolicy',
                                                                                                                 'RL_OM/agents/benchmark_agents/nv_agents.py'),
                                                         'RL_OM.agents.benchmark_agents.nv_agents.FakePolicy.reset': ( 'agents/benchmark_agents/basic_nv_agents.html#fakepolicy.reset',
                                                                                                                       'RL_OM/agents/benchmark_agents/nv_agents.py'),
                                                         'RL_OM.agents.benchmark_agents.nv_agents.ParametricAgent': ( 'agents/benchmark_agents/basic_nv_agents.html#parametricagent',
                                                                                                                      'RL_OM/agents/benchmark_agents/nv_agents.py'),
                                                         'RL_OM.agents.benchmark_agents.nv_agents.ParametricAgent.__init__': ( 'agents/benchmark_agents/basic_nv_agents.html#parametricagent.__init__',
                                                                                                                               'RL_OM/agents/benchmark_agents/nv_agents.py'),
                                                         'RL_OM.agents.benchmark_agents.nv_agents.ParametricAgent.draw_action': ( 'agents/benchmark_agents/basic_nv_agents.html#parametricagent.draw_action',
                                                                                                                                  'RL_OM/agents/benchmark_agents/nv_agents.py'),
                                                         'RL_OM.agents.benchmark_agents.nv_agents.ParametricAgent.fit': ( 'agents/benchmark_agents/basic_nv_agents.html#parametricagent.fit',
                                                                                                                          'RL_OM/agents/benchmark_agents/nv_agents.py'),
                                                         'RL_OM.agents.benchmark_agents.nv_agents.RandomAgent': ( 'agents/benchmark_agents/basic_nv_agents.html#randomagent',
                                                                                                                  'RL_OM/agents/benchmark_agents/nv_agents.py'),
                                                         'RL_OM.agents.benchmark_agents.nv_agents.RandomAgent.__init__': ( 'agents/benchmark_agents/basic_nv_agents.html#randomagent.__init__',
                                                                                                                           'RL_OM/agents/benchmark_agents/nv_agents.py'),
                                                         'RL_OM.agents.benchmark_agents.nv_agents.RandomAgent.draw_action': ( 'agents/benchmark_agents/basic_nv_agents.html#randomagent.draw_action',
                                                                                                                              'RL_OM/agents/benchmark_agents/nv_agents.py'),
                                                         'RL_OM.agents.benchmark_agents.nv_agents.RandomAgent.fit': ( 'agents/benchmark_agents/basic_nv_agents.html#randomagent.fit',
                                                                                                                      'RL_OM/agents/benchmark_agents/nv_agents.py')},
            'RL_OM.agents.benchmark_agents.nv_agents_ERM': { 'RL_OM.agents.benchmark_agents.nv_agents_ERM.Block': ( 'agents/benchmark_agents/erm_agents.html#block',
                                                                                                                    'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.Block.__init__': ( 'agents/benchmark_agents/erm_agents.html#block.__init__',
                                                                                                                             'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.Block.forward': ( 'agents/benchmark_agents/erm_agents.html#block.forward',
                                                                                                                            'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.CausalSelfAttention': ( 'agents/benchmark_agents/erm_agents.html#causalselfattention',
                                                                                                                                  'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.CausalSelfAttention.__init__': ( 'agents/benchmark_agents/erm_agents.html#causalselfattention.__init__',
                                                                                                                                           'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.CausalSelfAttention._init_rope': ( 'agents/benchmark_agents/erm_agents.html#causalselfattention._init_rope',
                                                                                                                                             'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.CausalSelfAttention.forward': ( 'agents/benchmark_agents/erm_agents.html#causalselfattention.forward',
                                                                                                                                          'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.FakePolicy': ( 'agents/benchmark_agents/erm_agents.html#fakepolicy',
                                                                                                                         'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.FakePolicy.reset': ( 'agents/benchmark_agents/erm_agents.html#fakepolicy.reset',
                                                                                                                               'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LERMsgdAgent': ( 'agents/benchmark_agents/erm_agents.html#lermsgdagent',
                                                                                                                           'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LERMsgdAgent.__init__': ( 'agents/benchmark_agents/erm_agents.html#lermsgdagent.__init__',
                                                                                                                                    'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LERMsgdAgent.draw_action': ( 'agents/benchmark_agents/erm_agents.html#lermsgdagent.draw_action',
                                                                                                                                       'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LERMsgdAgent.fit_epoch': ( 'agents/benchmark_agents/erm_agents.html#lermsgdagent.fit_epoch',
                                                                                                                                     'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LagLlama': ( 'agents/benchmark_agents/erm_agents.html#lagllama',
                                                                                                                       'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LagLlama.__init__': ( 'agents/benchmark_agents/erm_agents.html#lagllama.__init__',
                                                                                                                                'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LagLlama.forward': ( 'agents/benchmark_agents/erm_agents.html#lagllama.forward',
                                                                                                                               'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LagLlama.reset_cache': ( 'agents/benchmark_agents/erm_agents.html#lagllama.reset_cache',
                                                                                                                                   'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LagLlamasgdAgent': ( 'agents/benchmark_agents/erm_agents.html#lagllamasgdagent',
                                                                                                                               'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LagLlamasgdAgent.__init__': ( 'agents/benchmark_agents/erm_agents.html#lagllamasgdagent.__init__',
                                                                                                                                        'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LagLlamasgdAgent.draw_action': ( 'agents/benchmark_agents/erm_agents.html#lagllamasgdagent.draw_action',
                                                                                                                                           'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LagLlamasgdAgent.fit_epoch': ( 'agents/benchmark_agents/erm_agents.html#lagllamasgdagent.fit_epoch',
                                                                                                                                         'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LagLlamasgdMetaAgent': ( 'agents/benchmark_agents/erm_agents.html#lagllamasgdmetaagent',
                                                                                                                                   'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LagLlamasgdMetaAgent.__init__': ( 'agents/benchmark_agents/erm_agents.html#lagllamasgdmetaagent.__init__',
                                                                                                                                            'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LagLlamasgdMetaAgent.draw_action': ( 'agents/benchmark_agents/erm_agents.html#lagllamasgdmetaagent.draw_action',
                                                                                                                                               'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LagLlamasgdMetaAgent.fit': ( 'agents/benchmark_agents/erm_agents.html#lagllamasgdmetaagent.fit',
                                                                                                                                       'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LagLlamasgdMetaAgent.fit_epoch': ( 'agents/benchmark_agents/erm_agents.html#lagllamasgdmetaagent.fit_epoch',
                                                                                                                                             'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LagLlamasgdMetaAgent.pinball_loss': ( 'agents/benchmark_agents/erm_agents.html#lagllamasgdmetaagent.pinball_loss',
                                                                                                                                                'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LagLlamasgdMetaAgent.predict': ( 'agents/benchmark_agents/erm_agents.html#lagllamasgdmetaagent.predict',
                                                                                                                                           'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LinearModel': ( 'agents/benchmark_agents/erm_agents.html#linearmodel',
                                                                                                                          'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LinearModel.__init__': ( 'agents/benchmark_agents/erm_agents.html#linearmodel.__init__',
                                                                                                                                   'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LinearModel.forward': ( 'agents/benchmark_agents/erm_agents.html#linearmodel.forward',
                                                                                                                                  'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LlamaRotaryEmbedding': ( 'agents/benchmark_agents/erm_agents.html#llamarotaryembedding',
                                                                                                                                   'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LlamaRotaryEmbedding.__init__': ( 'agents/benchmark_agents/erm_agents.html#llamarotaryembedding.__init__',
                                                                                                                                            'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LlamaRotaryEmbedding._set_cos_sin_cache': ( 'agents/benchmark_agents/erm_agents.html#llamarotaryembedding._set_cos_sin_cache',
                                                                                                                                                      'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.LlamaRotaryEmbedding.forward': ( 'agents/benchmark_agents/erm_agents.html#llamarotaryembedding.forward',
                                                                                                                                           'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.MLP': ( 'agents/benchmark_agents/erm_agents.html#mlp',
                                                                                                                  'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.MLP.__init__': ( 'agents/benchmark_agents/erm_agents.html#mlp.__init__',
                                                                                                                           'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.MLP.forward': ( 'agents/benchmark_agents/erm_agents.html#mlp.forward',
                                                                                                                          'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.MLP_BLOCK': ( 'agents/benchmark_agents/erm_agents.html#mlp_block',
                                                                                                                        'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.MLP_BLOCK.__init__': ( 'agents/benchmark_agents/erm_agents.html#mlp_block.__init__',
                                                                                                                                 'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.MLP_BLOCK.forward': ( 'agents/benchmark_agents/erm_agents.html#mlp_block.forward',
                                                                                                                                'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.MLP_block': ( 'agents/benchmark_agents/erm_agents.html#mlp_block',
                                                                                                                        'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.MLP_block.__init__': ( 'agents/benchmark_agents/erm_agents.html#mlp_block.__init__',
                                                                                                                                 'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.MLP_block.forward': ( 'agents/benchmark_agents/erm_agents.html#mlp_block.forward',
                                                                                                                                'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.MLPsgdAgent': ( 'agents/benchmark_agents/erm_agents.html#mlpsgdagent',
                                                                                                                          'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.MLPsgdAgent.__init__': ( 'agents/benchmark_agents/erm_agents.html#mlpsgdagent.__init__',
                                                                                                                                   'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.MLPsgdAgent.draw_action': ( 'agents/benchmark_agents/erm_agents.html#mlpsgdagent.draw_action',
                                                                                                                                      'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.MLPsgdAgent.fit_epoch': ( 'agents/benchmark_agents/erm_agents.html#mlpsgdagent.fit_epoch',
                                                                                                                                    'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.NewsvendorData': ( 'agents/benchmark_agents/erm_agents.html#newsvendordata',
                                                                                                                             'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.NewsvendorData.__getitem__': ( 'agents/benchmark_agents/erm_agents.html#newsvendordata.__getitem__',
                                                                                                                                         'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.NewsvendorData.__init__': ( 'agents/benchmark_agents/erm_agents.html#newsvendordata.__init__',
                                                                                                                                      'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.NewsvendorData.__len__': ( 'agents/benchmark_agents/erm_agents.html#newsvendordata.__len__',
                                                                                                                                     'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.NewsvendorDataMeta': ( 'agents/benchmark_agents/erm_agents.html#newsvendordatameta',
                                                                                                                                 'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.NewsvendorDataMeta.__getitem__': ( 'agents/benchmark_agents/erm_agents.html#newsvendordatameta.__getitem__',
                                                                                                                                             'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.NewsvendorDataMeta.__init__': ( 'agents/benchmark_agents/erm_agents.html#newsvendordatameta.__init__',
                                                                                                                                          'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.NewsvendorDataMeta.__len__': ( 'agents/benchmark_agents/erm_agents.html#newsvendordatameta.__len__',
                                                                                                                                         'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.RMSNorm': ( 'agents/benchmark_agents/erm_agents.html#rmsnorm',
                                                                                                                      'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.RMSNorm.__init__': ( 'agents/benchmark_agents/erm_agents.html#rmsnorm.__init__',
                                                                                                                               'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.RMSNorm.forward': ( 'agents/benchmark_agents/erm_agents.html#rmsnorm.forward',
                                                                                                                              'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.RNN': ( 'agents/benchmark_agents/erm_agents.html#rnn',
                                                                                                                  'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.RNN.__init__': ( 'agents/benchmark_agents/erm_agents.html#rnn.__init__',
                                                                                                                           'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.RNN.forward': ( 'agents/benchmark_agents/erm_agents.html#rnn.forward',
                                                                                                                          'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.RNNsgdAgent': ( 'agents/benchmark_agents/erm_agents.html#rnnsgdagent',
                                                                                                                          'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.RNNsgdAgent.__init__': ( 'agents/benchmark_agents/erm_agents.html#rnnsgdagent.__init__',
                                                                                                                                   'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.RNNsgdAgent.draw_action': ( 'agents/benchmark_agents/erm_agents.html#rnnsgdagent.draw_action',
                                                                                                                                      'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.RNNsgdAgent.fit_epoch': ( 'agents/benchmark_agents/erm_agents.html#rnnsgdagent.fit_epoch',
                                                                                                                                    'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.RNNsgdMetaAgent': ( 'agents/benchmark_agents/erm_agents.html#rnnsgdmetaagent',
                                                                                                                              'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.RNNsgdMetaAgent.__init__': ( 'agents/benchmark_agents/erm_agents.html#rnnsgdmetaagent.__init__',
                                                                                                                                       'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.RNNsgdMetaAgent.draw_action': ( 'agents/benchmark_agents/erm_agents.html#rnnsgdmetaagent.draw_action',
                                                                                                                                          'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.RNNsgdMetaAgent.fit': ( 'agents/benchmark_agents/erm_agents.html#rnnsgdmetaagent.fit',
                                                                                                                                  'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.RNNsgdMetaAgent.fit_epoch': ( 'agents/benchmark_agents/erm_agents.html#rnnsgdmetaagent.fit_epoch',
                                                                                                                                        'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.RNNsgdMetaAgent.pinball_loss': ( 'agents/benchmark_agents/erm_agents.html#rnnsgdmetaagent.pinball_loss',
                                                                                                                                           'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.RNNsgdMetaAgent.predict': ( 'agents/benchmark_agents/erm_agents.html#rnnsgdmetaagent.predict',
                                                                                                                                      'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.SGDBase': ( 'agents/benchmark_agents/erm_agents.html#sgdbase',
                                                                                                                      'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.SGDBase.__init__': ( 'agents/benchmark_agents/erm_agents.html#sgdbase.__init__',
                                                                                                                               'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.SGDBase.eval': ( 'agents/benchmark_agents/erm_agents.html#sgdbase.eval',
                                                                                                                           'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.SGDBase.fit': ( 'agents/benchmark_agents/erm_agents.html#sgdbase.fit',
                                                                                                                          'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.SGDBase.max_or_zero': ( 'agents/benchmark_agents/erm_agents.html#sgdbase.max_or_zero',
                                                                                                                                  'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.SGDBase.pinball_loss': ( 'agents/benchmark_agents/erm_agents.html#sgdbase.pinball_loss',
                                                                                                                                   'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.SGDBase.predict': ( 'agents/benchmark_agents/erm_agents.html#sgdbase.predict',
                                                                                                                              'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.SGDBase.train': ( 'agents/benchmark_agents/erm_agents.html#sgdbase.train',
                                                                                                                            'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.apply_rotary_pos_emb': ( 'agents/benchmark_agents/erm_agents.html#apply_rotary_pos_emb',
                                                                                                                                   'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.find_multiple': ( 'agents/benchmark_agents/erm_agents.html#find_multiple',
                                                                                                                            'RL_OM/agents/benchmark_agents/nv_agents_ERM.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_ERM.rotate_half': ( 'agents/benchmark_agents/erm_agents.html#rotate_half',
                                                                                                                          'RL_OM/agents/benchmark_agents/nv_agents_ERM.py')},
            'RL_OM.agents.benchmark_agents.nv_agents_SAA': { 'RL_OM.agents.benchmark_agents.nv_agents_SAA.FakePolicy': ( 'agents/benchmark_agents/saa_agents.html#fakepolicy',
                                                                                                                         'RL_OM/agents/benchmark_agents/nv_agents_SAA.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_SAA.FakePolicy.reset': ( 'agents/benchmark_agents/saa_agents.html#fakepolicy.reset',
                                                                                                                               'RL_OM/agents/benchmark_agents/nv_agents_SAA.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_SAA.SAAAgent': ( 'agents/benchmark_agents/saa_agents.html#saaagent',
                                                                                                                       'RL_OM/agents/benchmark_agents/nv_agents_SAA.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_SAA.SAAAgent.__init__': ( 'agents/benchmark_agents/saa_agents.html#saaagent.__init__',
                                                                                                                                'RL_OM/agents/benchmark_agents/nv_agents_SAA.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_SAA.SAAAgent._calc_weights': ( 'agents/benchmark_agents/saa_agents.html#saaagent._calc_weights',
                                                                                                                                     'RL_OM/agents/benchmark_agents/nv_agents_SAA.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_SAA.SAAAgent._findQ': ( 'agents/benchmark_agents/saa_agents.html#saaagent._findq',
                                                                                                                              'RL_OM/agents/benchmark_agents/nv_agents_SAA.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_SAA.SAAAgent.draw_action': ( 'agents/benchmark_agents/saa_agents.html#saaagent.draw_action',
                                                                                                                                   'RL_OM/agents/benchmark_agents/nv_agents_SAA.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_SAA.SAAAgent.fit': ( 'agents/benchmark_agents/saa_agents.html#saaagent.fit',
                                                                                                                           'RL_OM/agents/benchmark_agents/nv_agents_SAA.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_SAA.WSAAAgent': ( 'agents/benchmark_agents/saa_agents.html#wsaaagent',
                                                                                                                        'RL_OM/agents/benchmark_agents/nv_agents_SAA.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_SAA.WSAAAgent.__init__': ( 'agents/benchmark_agents/saa_agents.html#wsaaagent.__init__',
                                                                                                                                 'RL_OM/agents/benchmark_agents/nv_agents_SAA.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_SAA.WSAAAgent._calc_weights': ( 'agents/benchmark_agents/saa_agents.html#wsaaagent._calc_weights',
                                                                                                                                      'RL_OM/agents/benchmark_agents/nv_agents_SAA.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_SAA.WSAAAgent._findQ': ( 'agents/benchmark_agents/saa_agents.html#wsaaagent._findq',
                                                                                                                               'RL_OM/agents/benchmark_agents/nv_agents_SAA.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_SAA.WSAAAgent._get_fitted_model': ( 'agents/benchmark_agents/saa_agents.html#wsaaagent._get_fitted_model',
                                                                                                                                          'RL_OM/agents/benchmark_agents/nv_agents_SAA.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_SAA.WSAAAgent.draw_action': ( 'agents/benchmark_agents/saa_agents.html#wsaaagent.draw_action',
                                                                                                                                    'RL_OM/agents/benchmark_agents/nv_agents_SAA.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_SAA.WSAAAgent.fit': ( 'agents/benchmark_agents/saa_agents.html#wsaaagent.fit',
                                                                                                                            'RL_OM/agents/benchmark_agents/nv_agents_SAA.py'),
                                                             'RL_OM.agents.benchmark_agents.nv_agents_SAA.check_cu_co': ( 'agents/benchmark_agents/saa_agents.html#check_cu_co',
                                                                                                                          'RL_OM/agents/benchmark_agents/nv_agents_SAA.py')},
            'RL_OM.agents.benchmark_agents.qr': { 'RL_OM.agents.benchmark_agents.qr.QRAgent': ( 'agents/benchmark_agents/qr.html#qragent',
                                                                                                'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRAgent.__init__': ( 'agents/benchmark_agents/qr.html#qragent.__init__',
                                                                                                         'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRAgent.fit': ( 'agents/benchmark_agents/qr.html#qragent.fit',
                                                                                                    'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRAgent_v2': ( 'agents/benchmark_agents/qr.html#qragent_v2',
                                                                                                   'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRAgent_v2.__init__': ( 'agents/benchmark_agents/qr.html#qragent_v2.__init__',
                                                                                                            'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRAgent_v2.fit': ( 'agents/benchmark_agents/qr.html#qragent_v2.fit',
                                                                                                       'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy': ( 'agents/benchmark_agents/qr.html#qrpolicy',
                                                                                                 'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy.__init__': ( 'agents/benchmark_agents/qr.html#qrpolicy.__init__',
                                                                                                          'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy.calculate_incremental_Q': ( 'agents/benchmark_agents/qr.html#qrpolicy.calculate_incremental_q',
                                                                                                                         'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy.calculate_incremental_R': ( 'agents/benchmark_agents/qr.html#qrpolicy.calculate_incremental_r',
                                                                                                                         'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy.calculate_initial_R': ( 'agents/benchmark_agents/qr.html#qrpolicy.calculate_initial_r',
                                                                                                                     'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy.draw_action': ( 'agents/benchmark_agents/qr.html#qrpolicy.draw_action',
                                                                                                             'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy.draw_action_train': ( 'agents/benchmark_agents/qr.html#qrpolicy.draw_action_train',
                                                                                                                   'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy.expected_stockouts': ( 'agents/benchmark_agents/qr.html#qrpolicy.expected_stockouts',
                                                                                                                    'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy.reset': ( 'agents/benchmark_agents/qr.html#qrpolicy.reset',
                                                                                                       'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy.run_simulation': ( 'agents/benchmark_agents/qr.html#qrpolicy.run_simulation',
                                                                                                                'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy.set_q_r': ( 'agents/benchmark_agents/qr.html#qrpolicy.set_q_r',
                                                                                                         'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy_v2': ( 'agents/benchmark_agents/qr.html#qrpolicy_v2',
                                                                                                    'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy_v2.__init__': ( 'agents/benchmark_agents/qr.html#qrpolicy_v2.__init__',
                                                                                                             'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy_v2.calculate_grid': ( 'agents/benchmark_agents/qr.html#qrpolicy_v2.calculate_grid',
                                                                                                                   'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy_v2.draw_action': ( 'agents/benchmark_agents/qr.html#qrpolicy_v2.draw_action',
                                                                                                                'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy_v2.draw_action_train': ( 'agents/benchmark_agents/qr.html#qrpolicy_v2.draw_action_train',
                                                                                                                      'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy_v2.reset': ( 'agents/benchmark_agents/qr.html#qrpolicy_v2.reset',
                                                                                                          'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy_v2.run_simulation': ( 'agents/benchmark_agents/qr.html#qrpolicy_v2.run_simulation',
                                                                                                                   'RL_OM/agents/benchmark_agents/qr.py'),
                                                  'RL_OM.agents.benchmark_agents.qr.QRPolicy_v2.set_q_r': ( 'agents/benchmark_agents/qr.html#qrpolicy_v2.set_q_r',
                                                                                                            'RL_OM/agents/benchmark_agents/qr.py')},
            'RL_OM.agents.benchmark_agents.saa': { 'RL_OM.agents.benchmark_agents.saa.SAA_MP_Agent': ( 'agents/benchmark_agents/saa_multi_period_agents.html#saa_mp_agent',
                                                                                                       'RL_OM/agents/benchmark_agents/saa.py'),
                                                   'RL_OM.agents.benchmark_agents.saa.SAA_MP_Agent.__init__': ( 'agents/benchmark_agents/saa_multi_period_agents.html#saa_mp_agent.__init__',
                                                                                                                'RL_OM/agents/benchmark_agents/saa.py'),
                                                   'RL_OM.agents.benchmark_agents.saa.SAA_MP_Agent.fit': ( 'agents/benchmark_agents/saa_multi_period_agents.html#saa_mp_agent.fit',
                                                                                                           'RL_OM/agents/benchmark_agents/saa.py'),
                                                   'RL_OM.agents.benchmark_agents.saa.SAA_MP_Policy': ( 'agents/benchmark_agents/saa_multi_period_agents.html#saa_mp_policy',
                                                                                                        'RL_OM/agents/benchmark_agents/saa.py'),
                                                   'RL_OM.agents.benchmark_agents.saa.SAA_MP_Policy.__init__': ( 'agents/benchmark_agents/saa_multi_period_agents.html#saa_mp_policy.__init__',
                                                                                                                 'RL_OM/agents/benchmark_agents/saa.py'),
                                                   'RL_OM.agents.benchmark_agents.saa.SAA_MP_Policy.draw_action': ( 'agents/benchmark_agents/saa_multi_period_agents.html#saa_mp_policy.draw_action',
                                                                                                                    'RL_OM/agents/benchmark_agents/saa.py'),
                                                   'RL_OM.agents.benchmark_agents.saa.SAA_MP_Policy.get_scenarios': ( 'agents/benchmark_agents/saa_multi_period_agents.html#saa_mp_policy.get_scenarios',
                                                                                                                      'RL_OM/agents/benchmark_agents/saa.py'),
                                                   'RL_OM.agents.benchmark_agents.saa.SAA_MP_Policy.optimize': ( 'agents/benchmark_agents/saa_multi_period_agents.html#saa_mp_policy.optimize',
                                                                                                                 'RL_OM/agents/benchmark_agents/saa.py'),
                                                   'RL_OM.agents.benchmark_agents.saa.SAA_MP_Policy.reset': ( 'agents/benchmark_agents/saa_multi_period_agents.html#saa_mp_policy.reset',
                                                                                                              'RL_OM/agents/benchmark_agents/saa.py'),
                                                   'RL_OM.agents.benchmark_agents.saa.SAA_MP_Policy.sample_scenarios': ( 'agents/benchmark_agents/saa_multi_period_agents.html#saa_mp_policy.sample_scenarios',
                                                                                                                         'RL_OM/agents/benchmark_agents/saa.py'),
                                                   'RL_OM.agents.benchmark_agents.saa.WSAA_MP_Agent': ( 'agents/benchmark_agents/saa_multi_period_agents.html#wsaa_mp_agent',
                                                                                                        'RL_OM/agents/benchmark_agents/saa.py'),
                                                   'RL_OM.agents.benchmark_agents.saa.WSAA_MP_Agent.__init__': ( 'agents/benchmark_agents/saa_multi_period_agents.html#wsaa_mp_agent.__init__',
                                                                                                                 'RL_OM/agents/benchmark_agents/saa.py'),
                                                   'RL_OM.agents.benchmark_agents.saa.WSAA_MP_Agent.fit': ( 'agents/benchmark_agents/saa_multi_period_agents.html#wsaa_mp_agent.fit',
                                                                                                            'RL_OM/agents/benchmark_agents/saa.py'),
                                                   'RL_OM.agents.benchmark_agents.saa.WSAA_MP_Policy': ( 'agents/benchmark_agents/saa_multi_period_agents.html#wsaa_mp_policy',
                                                                                                         'RL_OM/agents/benchmark_agents/saa.py'),
                                                   'RL_OM.agents.benchmark_agents.saa.WSAA_MP_Policy.__init__': ( 'agents/benchmark_agents/saa_multi_period_agents.html#wsaa_mp_policy.__init__',
                                                                                                                  'RL_OM/agents/benchmark_agents/saa.py'),
                                                   'RL_OM.agents.benchmark_agents.saa.WSAA_MP_Policy.get_scenarios': ( 'agents/benchmark_agents/saa_multi_period_agents.html#wsaa_mp_policy.get_scenarios',
                                                                                                                       'RL_OM/agents/benchmark_agents/saa.py'),
                                                   'RL_OM.agents.benchmark_agents.saa.WSAA_MP_Policy.reset': ( 'agents/benchmark_agents/saa_multi_period_agents.html#wsaa_mp_policy.reset',
                                                                                                               'RL_OM/agents/benchmark_agents/saa.py'),
                                                   'RL_OM.agents.benchmark_agents.saa.WSAA_MP_Policy.sample_scenarios': ( 'agents/benchmark_agents/saa_multi_period_agents.html#wsaa_mp_policy.sample_scenarios',
                                                                                                                          'RL_OM/agents/benchmark_agents/saa.py'),
                                                   'RL_OM.agents.benchmark_agents.saa.round_none': ( 'agents/benchmark_agents/saa_multi_period_agents.html#round_none',
                                                                                                     'RL_OM/agents/benchmark_agents/saa.py')},
            'RL_OM.agents.benchmark_agents.ss': { 'RL_OM.agents.benchmark_agents.ss.SSAgent': ( 'agents/benchmark_agents/ss.html#ssagent',
                                                                                                'RL_OM/agents/benchmark_agents/ss.py'),
                                                  'RL_OM.agents.benchmark_agents.ss.SSAgent.__init__': ( 'agents/benchmark_agents/ss.html#ssagent.__init__',
                                                                                                         'RL_OM/agents/benchmark_agents/ss.py'),
                                                  'RL_OM.agents.benchmark_agents.ss.SSAgent.fit': ( 'agents/benchmark_agents/ss.html#ssagent.fit',
                                                                                                    'RL_OM/agents/benchmark_agents/ss.py'),
                                                  'RL_OM.agents.benchmark_agents.ss.SSPolicy': ( 'agents/benchmark_agents/ss.html#sspolicy',
                                                                                                 'RL_OM/agents/benchmark_agents/ss.py'),
                                                  'RL_OM.agents.benchmark_agents.ss.SSPolicy.__init__': ( 'agents/benchmark_agents/ss.html#sspolicy.__init__',
                                                                                                          'RL_OM/agents/benchmark_agents/ss.py'),
                                                  'RL_OM.agents.benchmark_agents.ss.SSPolicy.calculate_grid': ( 'agents/benchmark_agents/ss.html#sspolicy.calculate_grid',
                                                                                                                'RL_OM/agents/benchmark_agents/ss.py'),
                                                  'RL_OM.agents.benchmark_agents.ss.SSPolicy.draw_action': ( 'agents/benchmark_agents/ss.html#sspolicy.draw_action',
                                                                                                             'RL_OM/agents/benchmark_agents/ss.py'),
                                                  'RL_OM.agents.benchmark_agents.ss.SSPolicy.draw_action_train': ( 'agents/benchmark_agents/ss.html#sspolicy.draw_action_train',
                                                                                                                   'RL_OM/agents/benchmark_agents/ss.py'),
                                                  'RL_OM.agents.benchmark_agents.ss.SSPolicy.reset': ( 'agents/benchmark_agents/ss.html#sspolicy.reset',
                                                                                                       'RL_OM/agents/benchmark_agents/ss.py'),
                                                  'RL_OM.agents.benchmark_agents.ss.SSPolicy.run_brute_variable': ( 'agents/benchmark_agents/ss.html#sspolicy.run_brute_variable',
                                                                                                                    'RL_OM/agents/benchmark_agents/ss.py'),
                                                  'RL_OM.agents.benchmark_agents.ss.SSPolicy.run_simulation': ( 'agents/benchmark_agents/ss.html#sspolicy.run_simulation',
                                                                                                                'RL_OM/agents/benchmark_agents/ss.py'),
                                                  'RL_OM.agents.benchmark_agents.ss.SSPolicy.set_and_calculate_grid': ( 'agents/benchmark_agents/ss.html#sspolicy.set_and_calculate_grid',
                                                                                                                        'RL_OM/agents/benchmark_agents/ss.py'),
                                                  'RL_OM.agents.benchmark_agents.ss.SSPolicy.set_s_S': ( 'agents/benchmark_agents/ss.html#sspolicy.set_s_s',
                                                                                                         'RL_OM/agents/benchmark_agents/ss.py')},
            'RL_OM.agents.networks.actors': { 'RL_OM.agents.networks.actors.ActorNetwork': ( 'agents/networks/actors.html#actornetwork',
                                                                                             'RL_OM/agents/networks/actors.py'),
                                              'RL_OM.agents.networks.actors.ActorNetwork.__init__': ( 'agents/networks/actors.html#actornetwork.__init__',
                                                                                                      'RL_OM/agents/networks/actors.py'),
                                              'RL_OM.agents.networks.actors.ActorNetwork.forward': ( 'agents/networks/actors.html#actornetwork.forward',
                                                                                                     'RL_OM/agents/networks/actors.py'),
                                              'RL_OM.agents.networks.actors.ActorNetworkDiscrete': ( 'agents/networks/actors.html#actornetworkdiscrete',
                                                                                                     'RL_OM/agents/networks/actors.py'),
                                              'RL_OM.agents.networks.actors.ActorNetworkDiscrete.__init__': ( 'agents/networks/actors.html#actornetworkdiscrete.__init__',
                                                                                                              'RL_OM/agents/networks/actors.py'),
                                              'RL_OM.agents.networks.actors.ActorNetworkDiscrete.forward': ( 'agents/networks/actors.html#actornetworkdiscrete.forward',
                                                                                                             'RL_OM/agents/networks/actors.py'),
                                              'RL_OM.agents.networks.actors.ActorNetworkRNN': ( 'agents/networks/actors.html#actornetworkrnn',
                                                                                                'RL_OM/agents/networks/actors.py'),
                                              'RL_OM.agents.networks.actors.ActorNetworkRNN.__init__': ( 'agents/networks/actors.html#actornetworkrnn.__init__',
                                                                                                         'RL_OM/agents/networks/actors.py'),
                                              'RL_OM.agents.networks.actors.ActorNetworkRNN.forward': ( 'agents/networks/actors.html#actornetworkrnn.forward',
                                                                                                        'RL_OM/agents/networks/actors.py'),
                                              'RL_OM.agents.networks.actors.ActorNetworkRNN_MLP_hybrid': ( 'agents/networks/actors.html#actornetworkrnn_mlp_hybrid',
                                                                                                           'RL_OM/agents/networks/actors.py'),
                                              'RL_OM.agents.networks.actors.ActorNetworkRNN_MLP_hybrid.__init__': ( 'agents/networks/actors.html#actornetworkrnn_mlp_hybrid.__init__',
                                                                                                                    'RL_OM/agents/networks/actors.py'),
                                              'RL_OM.agents.networks.actors.ActorNetworkRNN_MLP_hybrid.forward': ( 'agents/networks/actors.html#actornetworkrnn_mlp_hybrid.forward',
                                                                                                                   'RL_OM/agents/networks/actors.py')},
            'RL_OM.agents.networks.base': { 'RL_OM.agents.networks.base.BaseNetwork': ( 'agents/networks/base.html#basenetwork',
                                                                                        'RL_OM/agents/networks/base.py'),
                                            'RL_OM.agents.networks.base.BaseNetwork.__init__': ( 'agents/networks/base.html#basenetwork.__init__',
                                                                                                 'RL_OM/agents/networks/base.py'),
                                            'RL_OM.agents.networks.base.BaseNetwork.forward': ( 'agents/networks/base.html#basenetwork.forward',
                                                                                                'RL_OM/agents/networks/base.py')},
            'RL_OM.agents.networks.critics': { 'RL_OM.agents.networks.critics.CriticNetworkStandard': ( 'agents/networks/critics.html#criticnetworkstandard',
                                                                                                        'RL_OM/agents/networks/critics.py'),
                                               'RL_OM.agents.networks.critics.CriticNetworkStandard.__init__': ( 'agents/networks/critics.html#criticnetworkstandard.__init__',
                                                                                                                 'RL_OM/agents/networks/critics.py'),
                                               'RL_OM.agents.networks.critics.CriticNetworkStandard.forward': ( 'agents/networks/critics.html#criticnetworkstandard.forward',
                                                                                                                'RL_OM/agents/networks/critics.py'),
                                               'RL_OM.agents.networks.critics.CriticNetworkState': ( 'agents/networks/critics.html#criticnetworkstate',
                                                                                                     'RL_OM/agents/networks/critics.py'),
                                               'RL_OM.agents.networks.critics.CriticNetworkState.__init__': ( 'agents/networks/critics.html#criticnetworkstate.__init__',
                                                                                                              'RL_OM/agents/networks/critics.py'),
                                               'RL_OM.agents.networks.critics.CriticNetworkState.forward': ( 'agents/networks/critics.html#criticnetworkstate.forward',
                                                                                                             'RL_OM/agents/networks/critics.py'),
                                               'RL_OM.agents.networks.critics.CriticNetworkStateAction': ( 'agents/networks/critics.html#criticnetworkstateaction',
                                                                                                           'RL_OM/agents/networks/critics.py'),
                                               'RL_OM.agents.networks.critics.CriticNetworkStateAction.__init__': ( 'agents/networks/critics.html#criticnetworkstateaction.__init__',
                                                                                                                    'RL_OM/agents/networks/critics.py'),
                                               'RL_OM.agents.networks.critics.CriticNetworkStateAction.forward': ( 'agents/networks/critics.html#criticnetworkstateaction.forward',
                                                                                                                   'RL_OM/agents/networks/critics.py'),
                                               'RL_OM.agents.networks.critics.CriticNetworkStateActionRNN': ( 'agents/networks/critics.html#criticnetworkstateactionrnn',
                                                                                                              'RL_OM/agents/networks/critics.py'),
                                               'RL_OM.agents.networks.critics.CriticNetworkStateActionRNN.__init__': ( 'agents/networks/critics.html#criticnetworkstateactionrnn.__init__',
                                                                                                                       'RL_OM/agents/networks/critics.py'),
                                               'RL_OM.agents.networks.critics.CriticNetworkStateActionRNN.forward': ( 'agents/networks/critics.html#criticnetworkstateactionrnn.forward',
                                                                                                                      'RL_OM/agents/networks/critics.py'),
                                               'RL_OM.agents.networks.critics.CriticNetworkStateActionRNN_MLP_hybrid': ( 'agents/networks/critics.html#criticnetworkstateactionrnn_mlp_hybrid',
                                                                                                                         'RL_OM/agents/networks/critics.py'),
                                               'RL_OM.agents.networks.critics.CriticNetworkStateActionRNN_MLP_hybrid.__init__': ( 'agents/networks/critics.html#criticnetworkstateactionrnn_mlp_hybrid.__init__',
                                                                                                                                  'RL_OM/agents/networks/critics.py'),
                                               'RL_OM.agents.networks.critics.CriticNetworkStateActionRNN_MLP_hybrid.forward': ( 'agents/networks/critics.html#criticnetworkstateactionrnn_mlp_hybrid.forward',
                                                                                                                                 'RL_OM/agents/networks/critics.py')},
            'RL_OM.agents.processors.eoq_preprocessors': { 'RL_OM.agents.processors.eoq_preprocessors.GetInventory': ( 'agents/processors/eoq_preprocessors.html#getinventory',
                                                                                                                       'RL_OM/agents/processors/eoq_preprocessors.py'),
                                                           'RL_OM.agents.processors.eoq_preprocessors.GetInventory.__call__': ( 'agents/processors/eoq_preprocessors.html#getinventory.__call__',
                                                                                                                                'RL_OM/agents/processors/eoq_preprocessors.py'),
                                                           'RL_OM.agents.processors.eoq_preprocessors.GetInventory.__init__': ( 'agents/processors/eoq_preprocessors.html#getinventory.__init__',
                                                                                                                                'RL_OM/agents/processors/eoq_preprocessors.py')},
            'RL_OM.agents.processors.processors': { 'RL_OM.agents.processors.processors.ClipNegative': ( 'agents/processors/processors.html#clipnegative',
                                                                                                         'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.ClipNegative.__call__': ( 'agents/processors/processors.html#clipnegative.__call__',
                                                                                                                  'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.ContToBinary': ( 'agents/processors/processors.html#conttobinary',
                                                                                                         'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.ContToBinary.__call__': ( 'agents/processors/processors.html#conttobinary.__call__',
                                                                                                                  'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.ContToBinary.__init__': ( 'agents/processors/processors.html#conttobinary.__init__',
                                                                                                                  'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.DiscreteToContinuous': ( 'agents/processors/processors.html#discretetocontinuous',
                                                                                                                 'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.DiscreteToContinuous.__call__': ( 'agents/processors/processors.html#discretetocontinuous.__call__',
                                                                                                                          'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.DiscreteToContinuous.__init__': ( 'agents/processors/processors.html#discretetocontinuous.__init__',
                                                                                                                          'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.GetTimeSeriesAndStaticFeatures': ( 'agents/processors/processors.html#gettimeseriesandstaticfeatures',
                                                                                                                           'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.GetTimeSeriesAndStaticFeatures.__call__': ( 'agents/processors/processors.html#gettimeseriesandstaticfeatures.__call__',
                                                                                                                                    'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.GetTimeSeriesAndStaticFeatures.__init__': ( 'agents/processors/processors.html#gettimeseriesandstaticfeatures.__init__',
                                                                                                                                    'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.HybridToContinuous': ( 'agents/processors/processors.html#hybridtocontinuous',
                                                                                                               'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.HybridToContinuous.__call__': ( 'agents/processors/processors.html#hybridtocontinuous.__call__',
                                                                                                                        'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.HybridToContinuous.__init__': ( 'agents/processors/processors.html#hybridtocontinuous.__init__',
                                                                                                                        'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.MakeInputZero': ( 'agents/processors/processors.html#makeinputzero',
                                                                                                          'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.MakeInputZero.__call__': ( 'agents/processors/processors.html#makeinputzero.__call__',
                                                                                                                   'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.MakeInputZero.__init__': ( 'agents/processors/processors.html#makeinputzero.__init__',
                                                                                                                   'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.OneHotHybridtoContinuous': ( 'agents/processors/processors.html#onehothybridtocontinuous',
                                                                                                                     'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.OneHotHybridtoContinuous.__call__': ( 'agents/processors/processors.html#onehothybridtocontinuous.__call__',
                                                                                                                              'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.OneHotHybridtoContinuous.__init__': ( 'agents/processors/processors.html#onehothybridtocontinuous.__init__',
                                                                                                                              'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.OneHotToDiscrete': ( 'agents/processors/processors.html#onehottodiscrete',
                                                                                                             'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.OneHotToDiscrete.__call__': ( 'agents/processors/processors.html#onehottodiscrete.__call__',
                                                                                                                      'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.OneHotToDiscrete.__init__': ( 'agents/processors/processors.html#onehottodiscrete.__init__',
                                                                                                                      'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.RoundAction': ( 'agents/processors/processors.html#roundaction',
                                                                                                        'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.RoundAction.__call__': ( 'agents/processors/processors.html#roundaction.__call__',
                                                                                                                 'RL_OM/agents/processors/processors.py'),
                                                    'RL_OM.agents.processors.processors.RoundAction.__init__': ( 'agents/processors/processors.html#roundaction.__init__',
                                                                                                                 'RL_OM/agents/processors/processors.py')},
            'RL_OM.agents.rl_agents.algorithms.sac_discrete': { 'RL_OM.agents.rl_agents.algorithms.sac_discrete.GumbelSoftmax': ( 'agents/rl_agents/algorithms/sac_discrete.html#gumbelsoftmax',
                                                                                                                                  'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.GumbelSoftmax.entropy': ( 'agents/rl_agents/algorithms/sac_discrete.html#gumbelsoftmax.entropy',
                                                                                                                                          'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.GumbelSoftmax.log_prob': ( 'agents/rl_agents/algorithms/sac_discrete.html#gumbelsoftmax.log_prob',
                                                                                                                                           'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.GumbelSoftmax.rsample': ( 'agents/rl_agents/algorithms/sac_discrete.html#gumbelsoftmax.rsample',
                                                                                                                                          'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.GumbelSoftmax.sample': ( 'agents/rl_agents/algorithms/sac_discrete.html#gumbelsoftmax.sample',
                                                                                                                                         'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_Discrete_Policy': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete_policy',
                                                                                                                                        'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_Discrete_Policy.__call__': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete_policy.__call__',
                                                                                                                                                 'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_Discrete_Policy.__init__': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete_policy.__init__',
                                                                                                                                                 'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_Discrete_Policy.compute_action_and_log_prob': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete_policy.compute_action_and_log_prob',
                                                                                                                                                                    'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_Discrete_Policy.compute_action_and_log_prob_t': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete_policy.compute_action_and_log_prob_t',
                                                                                                                                                                      'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_Discrete_Policy.distribution': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete_policy.distribution',
                                                                                                                                                     'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_Discrete_Policy.draw_action': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete_policy.draw_action',
                                                                                                                                                    'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_Discrete_Policy.entropy': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete_policy.entropy',
                                                                                                                                                'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_Discrete_Policy.get_weights': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete_policy.get_weights',
                                                                                                                                                    'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_Discrete_Policy.parameters': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete_policy.parameters',
                                                                                                                                                   'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_Discrete_Policy.reset': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete_policy.reset',
                                                                                                                                              'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_Discrete_Policy.set_weights': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete_policy.set_weights',
                                                                                                                                                    'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_Discrete_Policy.use_cuda': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete_policy.use_cuda',
                                                                                                                                                 'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_discrete': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete',
                                                                                                                                 'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_discrete.__init__': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete.__init__',
                                                                                                                                          'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_discrete._alpha': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete._alpha',
                                                                                                                                        'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_discrete._alpha_np': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete._alpha_np',
                                                                                                                                           'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_discrete._loss': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete._loss',
                                                                                                                                       'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_discrete._next_q': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete._next_q',
                                                                                                                                         'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_discrete._post_load': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete._post_load',
                                                                                                                                            'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_discrete._update_alpha': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete._update_alpha',
                                                                                                                                               'RL_OM/agents/rl_agents/algorithms/sac_discrete.py'),
                                                                'RL_OM.agents.rl_agents.algorithms.sac_discrete.SAC_discrete.fit': ( 'agents/rl_agents/algorithms/sac_discrete.html#sac_discrete.fit',
                                                                                                                                     'RL_OM/agents/rl_agents/algorithms/sac_discrete.py')},
            'RL_OM.agents.rl_agents.algorithms.sac_gumbel': { 'RL_OM.agents.rl_agents.algorithms.sac_gumbel.GumbelSoftmax': ( 'agents/rl_agents/algorithms/sac_gumbel.html#gumbelsoftmax',
                                                                                                                              'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.GumbelSoftmax.entropy': ( 'agents/rl_agents/algorithms/sac_gumbel.html#gumbelsoftmax.entropy',
                                                                                                                                      'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.GumbelSoftmax.log_prob': ( 'agents/rl_agents/algorithms/sac_gumbel.html#gumbelsoftmax.log_prob',
                                                                                                                                       'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.GumbelSoftmax.rsample': ( 'agents/rl_agents/algorithms/sac_gumbel.html#gumbelsoftmax.rsample',
                                                                                                                                      'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.GumbelSoftmax.sample': ( 'agents/rl_agents/algorithms/sac_gumbel.html#gumbelsoftmax.sample',
                                                                                                                                     'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbel': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbel',
                                                                                                                           'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbel.__init__': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbel.__init__',
                                                                                                                                    'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbel._alpha': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbel._alpha',
                                                                                                                                  'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbel._alpha_np': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbel._alpha_np',
                                                                                                                                     'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbel._loss': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbel._loss',
                                                                                                                                 'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbel._next_q': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbel._next_q',
                                                                                                                                   'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbel._post_load': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbel._post_load',
                                                                                                                                      'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbel._update_alpha': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbel._update_alpha',
                                                                                                                                         'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbel.fit': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbel.fit',
                                                                                                                               'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbelPolicy': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbelpolicy',
                                                                                                                                 'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbelPolicy.__call__': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbelpolicy.__call__',
                                                                                                                                          'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbelPolicy.__init__': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbelpolicy.__init__',
                                                                                                                                          'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbelPolicy.compute_action_and_log_prob': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbelpolicy.compute_action_and_log_prob',
                                                                                                                                                             'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbelPolicy.compute_action_and_log_prob_t': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbelpolicy.compute_action_and_log_prob_t',
                                                                                                                                                               'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbelPolicy.distribution': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbelpolicy.distribution',
                                                                                                                                              'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbelPolicy.draw_action': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbelpolicy.draw_action',
                                                                                                                                             'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbelPolicy.entropy': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbelpolicy.entropy',
                                                                                                                                         'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbelPolicy.get_weights': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbelpolicy.get_weights',
                                                                                                                                             'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbelPolicy.parameters': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbelpolicy.parameters',
                                                                                                                                            'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbelPolicy.reset': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbelpolicy.reset',
                                                                                                                                       'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbelPolicy.set_weights': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbelpolicy.set_weights',
                                                                                                                                             'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_gumbel.SAC_gumbelPolicy.use_cuda': ( 'agents/rl_agents/algorithms/sac_gumbel.html#sac_gumbelpolicy.use_cuda',
                                                                                                                                          'RL_OM/agents/rl_agents/algorithms/sac_gumbel.py')},
            'RL_OM.agents.rl_agents.algorithms.sac_hybrid': { 'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybrid': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybrid',
                                                                                                                           'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybrid.__init__': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybrid.__init__',
                                                                                                                                    'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybrid._alpha': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybrid._alpha',
                                                                                                                                  'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybrid._alpha_np': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybrid._alpha_np',
                                                                                                                                     'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybrid._loss': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybrid._loss',
                                                                                                                                 'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybrid._next_q': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybrid._next_q',
                                                                                                                                   'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybrid._post_load': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybrid._post_load',
                                                                                                                                      'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybrid._update_alpha': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybrid._update_alpha',
                                                                                                                                         'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybrid.fit': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybrid.fit',
                                                                                                                               'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybridPolicy': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybridpolicy',
                                                                                                                                 'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybridPolicy.__call__': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybridpolicy.__call__',
                                                                                                                                          'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybridPolicy.__init__': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybridpolicy.__init__',
                                                                                                                                          'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybridPolicy.compute_action_and_log_prob': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybridpolicy.compute_action_and_log_prob',
                                                                                                                                                             'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybridPolicy.compute_action_and_log_prob_t': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybridpolicy.compute_action_and_log_prob_t',
                                                                                                                                                               'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybridPolicy.cont_distribution': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybridpolicy.cont_distribution',
                                                                                                                                                   'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybridPolicy.discrete_distribution': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybridpolicy.discrete_distribution',
                                                                                                                                                       'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybridPolicy.draw_action': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybridpolicy.draw_action',
                                                                                                                                             'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybridPolicy.draw_action_mean_and_logits': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybridpolicy.draw_action_mean_and_logits',
                                                                                                                                                             'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybridPolicy.draw_noisy_action': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybridpolicy.draw_noisy_action',
                                                                                                                                                   'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybridPolicy.entropy': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybridpolicy.entropy',
                                                                                                                                         'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybridPolicy.get_weights': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybridpolicy.get_weights',
                                                                                                                                             'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybridPolicy.parameters': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybridpolicy.parameters',
                                                                                                                                            'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybridPolicy.reset': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybridpolicy.reset',
                                                                                                                                       'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybridPolicy.set_weights': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybridpolicy.set_weights',
                                                                                                                                             'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py'),
                                                              'RL_OM.agents.rl_agents.algorithms.sac_hybrid.SAC_hybridPolicy.use_cuda': ( 'agents/rl_agents/algorithms/sac_hybrid.html#sac_hybridpolicy.use_cuda',
                                                                                                                                          'RL_OM/agents/rl_agents/algorithms/sac_hybrid.py')},
            'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed': { 'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybridPolicy': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybridpolicy',
                                                                                                                                                   'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybridPolicy.__call__': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybridpolicy.__call__',
                                                                                                                                                            'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybridPolicy.__init__': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybridpolicy.__init__',
                                                                                                                                                            'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybridPolicy.compute_action_and_log_prob': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybridpolicy.compute_action_and_log_prob',
                                                                                                                                                                               'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybridPolicy.compute_action_and_log_prob_t': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybridpolicy.compute_action_and_log_prob_t',
                                                                                                                                                                                 'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybridPolicy.cont_distribution': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybridpolicy.cont_distribution',
                                                                                                                                                                     'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybridPolicy.discrete_distribution': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybridpolicy.discrete_distribution',
                                                                                                                                                                         'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybridPolicy.draw_action': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybridpolicy.draw_action',
                                                                                                                                                               'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybridPolicy.draw_action_mean_and_logits': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybridpolicy.draw_action_mean_and_logits',
                                                                                                                                                                               'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybridPolicy.draw_noisy_action': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybridpolicy.draw_noisy_action',
                                                                                                                                                                     'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybridPolicy.entropy': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybridpolicy.entropy',
                                                                                                                                                           'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybridPolicy.get_weights': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybridpolicy.get_weights',
                                                                                                                                                               'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybridPolicy.parameters': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybridpolicy.parameters',
                                                                                                                                                              'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybridPolicy.reset': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybridpolicy.reset',
                                                                                                                                                         'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybridPolicy.set_weights': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybridpolicy.set_weights',
                                                                                                                                                               'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybridPolicy.use_cuda': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybridpolicy.use_cuda',
                                                                                                                                                            'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybrid_reversed': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybrid_reversed',
                                                                                                                                                      'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybrid_reversed.__init__': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybrid_reversed.__init__',
                                                                                                                                                               'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybrid_reversed._alpha': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybrid_reversed._alpha',
                                                                                                                                                             'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybrid_reversed._alpha_np': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybrid_reversed._alpha_np',
                                                                                                                                                                'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybrid_reversed._loss': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybrid_reversed._loss',
                                                                                                                                                            'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybrid_reversed._next_q': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybrid_reversed._next_q',
                                                                                                                                                              'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybrid_reversed._post_load': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybrid_reversed._post_load',
                                                                                                                                                                 'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybrid_reversed._update_alpha': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybrid_reversed._update_alpha',
                                                                                                                                                                    'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_reversed.SAC_hybrid_reversed.fit': ( 'agents/rl_agents/algorithms/sac_hybrid_reversed.html#sac_hybrid_reversed.fit',
                                                                                                                                                          'RL_OM/agents/rl_agents/algorithms/sac_hybrid_reversed.py')},
            'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate': { 'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybridPolicy': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybridpolicy',
                                                                                                                                                   'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybridPolicy.__call__': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybridpolicy.__call__',
                                                                                                                                                            'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybridPolicy.__init__': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybridpolicy.__init__',
                                                                                                                                                            'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybridPolicy.compute_action_and_log_prob': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybridpolicy.compute_action_and_log_prob',
                                                                                                                                                                               'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybridPolicy.compute_action_and_log_prob_t': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybridpolicy.compute_action_and_log_prob_t',
                                                                                                                                                                                 'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybridPolicy.cont_distribution': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybridpolicy.cont_distribution',
                                                                                                                                                                     'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybridPolicy.discrete_distribution': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybridpolicy.discrete_distribution',
                                                                                                                                                                         'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybridPolicy.draw_action': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybridpolicy.draw_action',
                                                                                                                                                               'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybridPolicy.draw_action_mean_and_logits': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybridpolicy.draw_action_mean_and_logits',
                                                                                                                                                                               'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybridPolicy.draw_noisy_action': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybridpolicy.draw_noisy_action',
                                                                                                                                                                     'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybridPolicy.entropy': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybridpolicy.entropy',
                                                                                                                                                           'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybridPolicy.get_weights': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybridpolicy.get_weights',
                                                                                                                                                               'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybridPolicy.parameters': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybridpolicy.parameters',
                                                                                                                                                              'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybridPolicy.reset': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybridpolicy.reset',
                                                                                                                                                         'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybridPolicy.set_weights': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybridpolicy.set_weights',
                                                                                                                                                               'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybridPolicy.use_cuda': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybridpolicy.use_cuda',
                                                                                                                                                            'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybrid_separate': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybrid_separate',
                                                                                                                                                      'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybrid_separate.__init__': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybrid_separate.__init__',
                                                                                                                                                               'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybrid_separate._alpha': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybrid_separate._alpha',
                                                                                                                                                             'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybrid_separate._alpha_np': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybrid_separate._alpha_np',
                                                                                                                                                                'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybrid_separate._loss': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybrid_separate._loss',
                                                                                                                                                            'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybrid_separate._next_q': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybrid_separate._next_q',
                                                                                                                                                              'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybrid_separate._post_load': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybrid_separate._post_load',
                                                                                                                                                                 'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybrid_separate._update_alpha': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybrid_separate._update_alpha',
                                                                                                                                                                    'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py'),
                                                                       'RL_OM.agents.rl_agents.algorithms.sac_hybrid_separate.SAC_hybrid_separate.fit': ( 'agents/rl_agents/algorithms/sac_hybrid_separate.html#sac_hybrid_separate.fit',
                                                                                                                                                          'RL_OM/agents/rl_agents/algorithms/sac_hybrid_separate.py')},
            'RL_OM.agents.rl_agents.pre_specified_agents.PPO_classic': { 'RL_OM.agents.rl_agents.pre_specified_agents.PPO_classic.PPOClassic': ( 'agents/rl_agents/pre_specified_agents/ppo_classic.html#ppoclassic',
                                                                                                                                                 'RL_OM/agents/rl_agents/pre_specified_agents/PPO_classic.py'),
                                                                         'RL_OM.agents.rl_agents.pre_specified_agents.PPO_classic.PPOClassic.__getattr__': ( 'agents/rl_agents/pre_specified_agents/ppo_classic.html#ppoclassic.__getattr__',
                                                                                                                                                             'RL_OM/agents/rl_agents/pre_specified_agents/PPO_classic.py'),
                                                                         'RL_OM.agents.rl_agents.pre_specified_agents.PPO_classic.PPOClassic.__init__': ( 'agents/rl_agents/pre_specified_agents/ppo_classic.html#ppoclassic.__init__',
                                                                                                                                                          'RL_OM/agents/rl_agents/pre_specified_agents/PPO_classic.py')},
            'RL_OM.agents.rl_agents.pre_specified_agents.SAC_RNN': { 'RL_OM.agents.rl_agents.pre_specified_agents.SAC_RNN.SACRNN': ( 'agents/rl_agents/pre_specified_agents/sac_rnn.html#sacrnn',
                                                                                                                                     'RL_OM/agents/rl_agents/pre_specified_agents/SAC_RNN.py'),
                                                                     'RL_OM.agents.rl_agents.pre_specified_agents.SAC_RNN.SACRNN.__getattr__': ( 'agents/rl_agents/pre_specified_agents/sac_rnn.html#sacrnn.__getattr__',
                                                                                                                                                 'RL_OM/agents/rl_agents/pre_specified_agents/SAC_RNN.py'),
                                                                     'RL_OM.agents.rl_agents.pre_specified_agents.SAC_RNN.SACRNN.__init__': ( 'agents/rl_agents/pre_specified_agents/sac_rnn.html#sacrnn.__init__',
                                                                                                                                              'RL_OM/agents/rl_agents/pre_specified_agents/SAC_RNN.py'),
                                                                     'RL_OM.agents.rl_agents.pre_specified_agents.SAC_RNN.SACRNN_hybrid': ( 'agents/rl_agents/pre_specified_agents/sac_rnn.html#sacrnn_hybrid',
                                                                                                                                            'RL_OM/agents/rl_agents/pre_specified_agents/SAC_RNN.py'),
                                                                     'RL_OM.agents.rl_agents.pre_specified_agents.SAC_RNN.SACRNN_hybrid.__getattr__': ( 'agents/rl_agents/pre_specified_agents/sac_rnn.html#sacrnn_hybrid.__getattr__',
                                                                                                                                                        'RL_OM/agents/rl_agents/pre_specified_agents/SAC_RNN.py'),
                                                                     'RL_OM.agents.rl_agents.pre_specified_agents.SAC_RNN.SACRNN_hybrid.__init__': ( 'agents/rl_agents/pre_specified_agents/sac_rnn.html#sacrnn_hybrid.__init__',
                                                                                                                                                     'RL_OM/agents/rl_agents/pre_specified_agents/SAC_RNN.py')},
            'RL_OM.agents.rl_agents.pre_specified_agents.SAC_classic': { 'RL_OM.agents.rl_agents.pre_specified_agents.SAC_classic.SACClassic': ( 'agents/rl_agents/pre_specified_agents/sac_classic.html#sacclassic',
                                                                                                                                                 'RL_OM/agents/rl_agents/pre_specified_agents/SAC_classic.py'),
                                                                         'RL_OM.agents.rl_agents.pre_specified_agents.SAC_classic.SACClassic.__getattr__': ( 'agents/rl_agents/pre_specified_agents/sac_classic.html#sacclassic.__getattr__',
                                                                                                                                                             'RL_OM/agents/rl_agents/pre_specified_agents/SAC_classic.py'),
                                                                         'RL_OM.agents.rl_agents.pre_specified_agents.SAC_classic.SACClassic.__init__': ( 'agents/rl_agents/pre_specified_agents/sac_classic.html#sacclassic.__init__',
                                                                                                                                                          'RL_OM/agents/rl_agents/pre_specified_agents/SAC_classic.py')},
            'RL_OM.agents.rl_agents.pre_specified_agents.SAC_discrete': { 'RL_OM.agents.rl_agents.pre_specified_agents.SAC_discrete.SACDiscrete': ( 'agents/rl_agents/pre_specified_agents/sac_discrete.html#sacdiscrete',
                                                                                                                                                    'RL_OM/agents/rl_agents/pre_specified_agents/SAC_discrete.py'),
                                                                          'RL_OM.agents.rl_agents.pre_specified_agents.SAC_discrete.SACDiscrete.__getattr__': ( 'agents/rl_agents/pre_specified_agents/sac_discrete.html#sacdiscrete.__getattr__',
                                                                                                                                                                'RL_OM/agents/rl_agents/pre_specified_agents/SAC_discrete.py'),
                                                                          'RL_OM.agents.rl_agents.pre_specified_agents.SAC_discrete.SACDiscrete.__init__': ( 'agents/rl_agents/pre_specified_agents/sac_discrete.html#sacdiscrete.__init__',
                                                                                                                                                             'RL_OM/agents/rl_agents/pre_specified_agents/SAC_discrete.py')},
            'RL_OM.agents.rl_agents.pre_specified_agents.SAC_gumbel': { 'RL_OM.agents.rl_agents.pre_specified_agents.SAC_gumbel.SACGumbel': ( 'agents/rl_agents/pre_specified_agents/sac_gumbel.html#sacgumbel',
                                                                                                                                              'RL_OM/agents/rl_agents/pre_specified_agents/SAC_gumbel.py'),
                                                                        'RL_OM.agents.rl_agents.pre_specified_agents.SAC_gumbel.SACGumbel.__getattr__': ( 'agents/rl_agents/pre_specified_agents/sac_gumbel.html#sacgumbel.__getattr__',
                                                                                                                                                          'RL_OM/agents/rl_agents/pre_specified_agents/SAC_gumbel.py'),
                                                                        'RL_OM.agents.rl_agents.pre_specified_agents.SAC_gumbel.SACGumbel.__init__': ( 'agents/rl_agents/pre_specified_agents/sac_gumbel.html#sacgumbel.__init__',
                                                                                                                                                       'RL_OM/agents/rl_agents/pre_specified_agents/SAC_gumbel.py')},
            'RL_OM.agents.rl_agents.pre_specified_agents.SAC_hybrid_gumbel': { 'RL_OM.agents.rl_agents.pre_specified_agents.SAC_hybrid_gumbel.SACHybridGumbel': ( 'agents/rl_agents/pre_specified_agents/sac_hybrid_gumbel.html#sachybridgumbel',
                                                                                                                                                                  'RL_OM/agents/rl_agents/pre_specified_agents/SAC_hybrid_gumbel.py'),
                                                                               'RL_OM.agents.rl_agents.pre_specified_agents.SAC_hybrid_gumbel.SACHybridGumbel.__getattr__': ( 'agents/rl_agents/pre_specified_agents/sac_hybrid_gumbel.html#sachybridgumbel.__getattr__',
                                                                                                                                                                              'RL_OM/agents/rl_agents/pre_specified_agents/SAC_hybrid_gumbel.py'),
                                                                               'RL_OM.agents.rl_agents.pre_specified_agents.SAC_hybrid_gumbel.SACHybridGumbel.__init__': ( 'agents/rl_agents/pre_specified_agents/sac_hybrid_gumbel.html#sachybridgumbel.__init__',
                                                                                                                                                                           'RL_OM/agents/rl_agents/pre_specified_agents/SAC_hybrid_gumbel.py'),
                                                                               'RL_OM.agents.rl_agents.pre_specified_agents.SAC_hybrid_gumbel.SACHybridGumbelReversed': ( 'agents/rl_agents/pre_specified_agents/sac_hybrid_gumbel.html#sachybridgumbelreversed',
                                                                                                                                                                          'RL_OM/agents/rl_agents/pre_specified_agents/SAC_hybrid_gumbel.py'),
                                                                               'RL_OM.agents.rl_agents.pre_specified_agents.SAC_hybrid_gumbel.SACHybridGumbelReversed.__getattr__': ( 'agents/rl_agents/pre_specified_agents/sac_hybrid_gumbel.html#sachybridgumbelreversed.__getattr__',
                                                                                                                                                                                      'RL_OM/agents/rl_agents/pre_specified_agents/SAC_hybrid_gumbel.py'),
                                                                               'RL_OM.agents.rl_agents.pre_specified_agents.SAC_hybrid_gumbel.SACHybridGumbelReversed.__init__': ( 'agents/rl_agents/pre_specified_agents/sac_hybrid_gumbel.html#sachybridgumbelreversed.__init__',
                                                                                                                                                                                   'RL_OM/agents/rl_agents/pre_specified_agents/SAC_hybrid_gumbel.py'),
                                                                               'RL_OM.agents.rl_agents.pre_specified_agents.SAC_hybrid_gumbel.SACHybridGumbelSeparate': ( 'agents/rl_agents/pre_specified_agents/sac_hybrid_gumbel.html#sachybridgumbelseparate',
                                                                                                                                                                          'RL_OM/agents/rl_agents/pre_specified_agents/SAC_hybrid_gumbel.py'),
                                                                               'RL_OM.agents.rl_agents.pre_specified_agents.SAC_hybrid_gumbel.SACHybridGumbelSeparate.__getattr__': ( 'agents/rl_agents/pre_specified_agents/sac_hybrid_gumbel.html#sachybridgumbelseparate.__getattr__',
                                                                                                                                                                                      'RL_OM/agents/rl_agents/pre_specified_agents/SAC_hybrid_gumbel.py'),
                                                                               'RL_OM.agents.rl_agents.pre_specified_agents.SAC_hybrid_gumbel.SACHybridGumbelSeparate.__init__': ( 'agents/rl_agents/pre_specified_agents/sac_hybrid_gumbel.html#sachybridgumbelseparate.__init__',
                                                                                                                                                                                   'RL_OM/agents/rl_agents/pre_specified_agents/SAC_hybrid_gumbel.py')},
            'RL_OM.agents.rl_agents.pre_specified_agents.SAC_hybrid_naive': { 'RL_OM.agents.rl_agents.pre_specified_agents.SAC_hybrid_naive.SACHybridNaive': ( 'agents/rl_agents/pre_specified_agents/sac_hybrid_naive.html#sachybridnaive',
                                                                                                                                                               'RL_OM/agents/rl_agents/pre_specified_agents/SAC_hybrid_naive.py'),
                                                                              'RL_OM.agents.rl_agents.pre_specified_agents.SAC_hybrid_naive.SACHybridNaive.__getattr__': ( 'agents/rl_agents/pre_specified_agents/sac_hybrid_naive.html#sachybridnaive.__getattr__',
                                                                                                                                                                           'RL_OM/agents/rl_agents/pre_specified_agents/SAC_hybrid_naive.py'),
                                                                              'RL_OM.agents.rl_agents.pre_specified_agents.SAC_hybrid_naive.SACHybridNaive.__init__': ( 'agents/rl_agents/pre_specified_agents/sac_hybrid_naive.html#sachybridnaive.__init__',
                                                                                                                                                                        'RL_OM/agents/rl_agents/pre_specified_agents/SAC_hybrid_naive.py')},
            'RL_OM.agents.rl_agents.pre_specified_agents.TD3_classic': { 'RL_OM.agents.rl_agents.pre_specified_agents.TD3_classic.TD3Classic': ( 'agents/rl_agents/pre_specified_agents/td3_classic.html#td3classic',
                                                                                                                                                 'RL_OM/agents/rl_agents/pre_specified_agents/TD3_classic.py'),
                                                                         'RL_OM.agents.rl_agents.pre_specified_agents.TD3_classic.TD3Classic.__getattr__': ( 'agents/rl_agents/pre_specified_agents/td3_classic.html#td3classic.__getattr__',
                                                                                                                                                             'RL_OM/agents/rl_agents/pre_specified_agents/TD3_classic.py'),
                                                                         'RL_OM.agents.rl_agents.pre_specified_agents.TD3_classic.TD3Classic.__init__': ( 'agents/rl_agents/pre_specified_agents/td3_classic.html#td3classic.__init__',
                                                                                                                                                          'RL_OM/agents/rl_agents/pre_specified_agents/TD3_classic.py')},
            'RL_OM.agents.rl_agents.sac_discrete': { 'RL_OM.agents.rl_agents.sac_discrete.GumbelSoftmax': ( 'agents/rl_agents/sac_discrete.html#gumbelsoftmax',
                                                                                                            'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.GumbelSoftmax.entropy': ( 'agents/rl_agents/sac_discrete.html#gumbelsoftmax.entropy',
                                                                                                                    'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.GumbelSoftmax.log_prob': ( 'agents/rl_agents/sac_discrete.html#gumbelsoftmax.log_prob',
                                                                                                                     'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.GumbelSoftmax.rsample': ( 'agents/rl_agents/sac_discrete.html#gumbelsoftmax.rsample',
                                                                                                                    'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.GumbelSoftmax.sample': ( 'agents/rl_agents/sac_discrete.html#gumbelsoftmax.sample',
                                                                                                                   'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_Discrete_Policy': ( 'agents/rl_agents/sac_discrete.html#sac_discrete_policy',
                                                                                                                  'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_Discrete_Policy.__call__': ( 'agents/rl_agents/sac_discrete.html#sac_discrete_policy.__call__',
                                                                                                                           'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_Discrete_Policy.__init__': ( 'agents/rl_agents/sac_discrete.html#sac_discrete_policy.__init__',
                                                                                                                           'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_Discrete_Policy.compute_action_and_log_prob': ( 'agents/rl_agents/sac_discrete.html#sac_discrete_policy.compute_action_and_log_prob',
                                                                                                                                              'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_Discrete_Policy.compute_action_and_log_prob_t': ( 'agents/rl_agents/sac_discrete.html#sac_discrete_policy.compute_action_and_log_prob_t',
                                                                                                                                                'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_Discrete_Policy.distribution': ( 'agents/rl_agents/sac_discrete.html#sac_discrete_policy.distribution',
                                                                                                                               'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_Discrete_Policy.draw_action': ( 'agents/rl_agents/sac_discrete.html#sac_discrete_policy.draw_action',
                                                                                                                              'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_Discrete_Policy.entropy': ( 'agents/rl_agents/sac_discrete.html#sac_discrete_policy.entropy',
                                                                                                                          'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_Discrete_Policy.get_weights': ( 'agents/rl_agents/sac_discrete.html#sac_discrete_policy.get_weights',
                                                                                                                              'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_Discrete_Policy.parameters': ( 'agents/rl_agents/sac_discrete.html#sac_discrete_policy.parameters',
                                                                                                                             'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_Discrete_Policy.reset': ( 'agents/rl_agents/sac_discrete.html#sac_discrete_policy.reset',
                                                                                                                        'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_Discrete_Policy.set_weights': ( 'agents/rl_agents/sac_discrete.html#sac_discrete_policy.set_weights',
                                                                                                                              'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_Discrete_Policy.use_cuda': ( 'agents/rl_agents/sac_discrete.html#sac_discrete_policy.use_cuda',
                                                                                                                           'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_discrete': ( 'agents/rl_agents/sac_discrete.html#sac_discrete',
                                                                                                           'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_discrete.__init__': ( 'agents/rl_agents/sac_discrete.html#sac_discrete.__init__',
                                                                                                                    'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_discrete._alpha': ( 'agents/rl_agents/sac_discrete.html#sac_discrete._alpha',
                                                                                                                  'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_discrete._alpha_np': ( 'agents/rl_agents/sac_discrete.html#sac_discrete._alpha_np',
                                                                                                                     'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_discrete._loss': ( 'agents/rl_agents/sac_discrete.html#sac_discrete._loss',
                                                                                                                 'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_discrete._next_q': ( 'agents/rl_agents/sac_discrete.html#sac_discrete._next_q',
                                                                                                                   'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_discrete._post_load': ( 'agents/rl_agents/sac_discrete.html#sac_discrete._post_load',
                                                                                                                      'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_discrete._update_alpha': ( 'agents/rl_agents/sac_discrete.html#sac_discrete._update_alpha',
                                                                                                                         'RL_OM/agents/rl_agents/sac_discrete.py'),
                                                     'RL_OM.agents.rl_agents.sac_discrete.SAC_discrete.fit': ( 'agents/rl_agents/sac_discrete.html#sac_discrete.fit',
                                                                                                               'RL_OM/agents/rl_agents/sac_discrete.py')},
            'RL_OM.agents.rl_agents.sac_gumbel': { 'RL_OM.agents.rl_agents.sac_gumbel.GumbelSoftmax': ( 'agents/rl_agents/sac_gumbel.html#gumbelsoftmax',
                                                                                                        'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.GumbelSoftmax.entropy': ( 'agents/rl_agents/sac_gumbel.html#gumbelsoftmax.entropy',
                                                                                                                'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.GumbelSoftmax.log_prob': ( 'agents/rl_agents/sac_gumbel.html#gumbelsoftmax.log_prob',
                                                                                                                 'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.GumbelSoftmax.rsample': ( 'agents/rl_agents/sac_gumbel.html#gumbelsoftmax.rsample',
                                                                                                                'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.GumbelSoftmax.sample': ( 'agents/rl_agents/sac_gumbel.html#gumbelsoftmax.sample',
                                                                                                               'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbel': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbel',
                                                                                                     'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbel.__init__': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbel.__init__',
                                                                                                              'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbel._alpha': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbel._alpha',
                                                                                                            'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbel._alpha_np': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbel._alpha_np',
                                                                                                               'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbel._loss': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbel._loss',
                                                                                                           'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbel._next_q': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbel._next_q',
                                                                                                             'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbel._post_load': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbel._post_load',
                                                                                                                'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbel._update_alpha': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbel._update_alpha',
                                                                                                                   'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbel.fit': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbel.fit',
                                                                                                         'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbelPolicy': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbelpolicy',
                                                                                                           'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbelPolicy.__call__': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbelpolicy.__call__',
                                                                                                                    'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbelPolicy.__init__': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbelpolicy.__init__',
                                                                                                                    'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbelPolicy.compute_action_and_log_prob': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbelpolicy.compute_action_and_log_prob',
                                                                                                                                       'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbelPolicy.compute_action_and_log_prob_t': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbelpolicy.compute_action_and_log_prob_t',
                                                                                                                                         'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbelPolicy.distribution': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbelpolicy.distribution',
                                                                                                                        'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbelPolicy.draw_action': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbelpolicy.draw_action',
                                                                                                                       'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbelPolicy.entropy': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbelpolicy.entropy',
                                                                                                                   'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbelPolicy.get_weights': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbelpolicy.get_weights',
                                                                                                                       'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbelPolicy.parameters': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbelpolicy.parameters',
                                                                                                                      'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbelPolicy.reset': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbelpolicy.reset',
                                                                                                                 'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbelPolicy.set_weights': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbelpolicy.set_weights',
                                                                                                                       'RL_OM/agents/rl_agents/sac_gumbel.py'),
                                                   'RL_OM.agents.rl_agents.sac_gumbel.SAC_gumbelPolicy.use_cuda': ( 'agents/rl_agents/sac_gumbel.html#sac_gumbelpolicy.use_cuda',
                                                                                                                    'RL_OM/agents/rl_agents/sac_gumbel.py')},
            'RL_OM.agents.rl_agents.sac_hybrid': { 'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybrid': ( 'agents/rl_agents/sac_hybrid.html#sac_hybrid',
                                                                                                     'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybrid.__init__': ( 'agents/rl_agents/sac_hybrid.html#sac_hybrid.__init__',
                                                                                                              'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybrid._alpha': ( 'agents/rl_agents/sac_hybrid.html#sac_hybrid._alpha',
                                                                                                            'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybrid._alpha_np': ( 'agents/rl_agents/sac_hybrid.html#sac_hybrid._alpha_np',
                                                                                                               'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybrid._loss': ( 'agents/rl_agents/sac_hybrid.html#sac_hybrid._loss',
                                                                                                           'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybrid._next_q': ( 'agents/rl_agents/sac_hybrid.html#sac_hybrid._next_q',
                                                                                                             'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybrid._post_load': ( 'agents/rl_agents/sac_hybrid.html#sac_hybrid._post_load',
                                                                                                                'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybrid._update_alpha': ( 'agents/rl_agents/sac_hybrid.html#sac_hybrid._update_alpha',
                                                                                                                   'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybrid.fit': ( 'agents/rl_agents/sac_hybrid.html#sac_hybrid.fit',
                                                                                                         'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybridPolicy': ( 'agents/rl_agents/sac_hybrid.html#sac_hybridpolicy',
                                                                                                           'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybridPolicy.__call__': ( 'agents/rl_agents/sac_hybrid.html#sac_hybridpolicy.__call__',
                                                                                                                    'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybridPolicy.__init__': ( 'agents/rl_agents/sac_hybrid.html#sac_hybridpolicy.__init__',
                                                                                                                    'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybridPolicy.compute_action_and_log_prob': ( 'agents/rl_agents/sac_hybrid.html#sac_hybridpolicy.compute_action_and_log_prob',
                                                                                                                                       'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybridPolicy.compute_action_and_log_prob_t': ( 'agents/rl_agents/sac_hybrid.html#sac_hybridpolicy.compute_action_and_log_prob_t',
                                                                                                                                         'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybridPolicy.cont_distribution': ( 'agents/rl_agents/sac_hybrid.html#sac_hybridpolicy.cont_distribution',
                                                                                                                             'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybridPolicy.discrete_distribution': ( 'agents/rl_agents/sac_hybrid.html#sac_hybridpolicy.discrete_distribution',
                                                                                                                                 'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybridPolicy.draw_action': ( 'agents/rl_agents/sac_hybrid.html#sac_hybridpolicy.draw_action',
                                                                                                                       'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybridPolicy.draw_action_mean_and_logits': ( 'agents/rl_agents/sac_hybrid.html#sac_hybridpolicy.draw_action_mean_and_logits',
                                                                                                                                       'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybridPolicy.draw_noisy_action': ( 'agents/rl_agents/sac_hybrid.html#sac_hybridpolicy.draw_noisy_action',
                                                                                                                             'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybridPolicy.entropy': ( 'agents/rl_agents/sac_hybrid.html#sac_hybridpolicy.entropy',
                                                                                                                   'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybridPolicy.get_weights': ( 'agents/rl_agents/sac_hybrid.html#sac_hybridpolicy.get_weights',
                                                                                                                       'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybridPolicy.parameters': ( 'agents/rl_agents/sac_hybrid.html#sac_hybridpolicy.parameters',
                                                                                                                      'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybridPolicy.reset': ( 'agents/rl_agents/sac_hybrid.html#sac_hybridpolicy.reset',
                                                                                                                 'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybridPolicy.set_weights': ( 'agents/rl_agents/sac_hybrid.html#sac_hybridpolicy.set_weights',
                                                                                                                       'RL_OM/agents/rl_agents/sac_hybrid.py'),
                                                   'RL_OM.agents.rl_agents.sac_hybrid.SAC_hybridPolicy.use_cuda': ( 'agents/rl_agents/sac_hybrid.html#sac_hybridpolicy.use_cuda',
                                                                                                                    'RL_OM/agents/rl_agents/sac_hybrid.py')},
            'RL_OM.agents.rl_agents.sac_hybrid_reversed': { 'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybridPolicy': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybridpolicy',
                                                                                                                             'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybridPolicy.__call__': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybridpolicy.__call__',
                                                                                                                                      'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybridPolicy.__init__': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybridpolicy.__init__',
                                                                                                                                      'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybridPolicy.compute_action_and_log_prob': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybridpolicy.compute_action_and_log_prob',
                                                                                                                                                         'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybridPolicy.compute_action_and_log_prob_t': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybridpolicy.compute_action_and_log_prob_t',
                                                                                                                                                           'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybridPolicy.cont_distribution': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybridpolicy.cont_distribution',
                                                                                                                                               'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybridPolicy.discrete_distribution': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybridpolicy.discrete_distribution',
                                                                                                                                                   'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybridPolicy.draw_action': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybridpolicy.draw_action',
                                                                                                                                         'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybridPolicy.draw_action_mean_and_logits': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybridpolicy.draw_action_mean_and_logits',
                                                                                                                                                         'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybridPolicy.draw_noisy_action': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybridpolicy.draw_noisy_action',
                                                                                                                                               'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybridPolicy.entropy': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybridpolicy.entropy',
                                                                                                                                     'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybridPolicy.get_weights': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybridpolicy.get_weights',
                                                                                                                                         'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybridPolicy.parameters': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybridpolicy.parameters',
                                                                                                                                        'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybridPolicy.reset': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybridpolicy.reset',
                                                                                                                                   'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybridPolicy.set_weights': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybridpolicy.set_weights',
                                                                                                                                         'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybridPolicy.use_cuda': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybridpolicy.use_cuda',
                                                                                                                                      'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybrid_reversed': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybrid_reversed',
                                                                                                                                'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybrid_reversed.__init__': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybrid_reversed.__init__',
                                                                                                                                         'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybrid_reversed._alpha': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybrid_reversed._alpha',
                                                                                                                                       'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybrid_reversed._alpha_np': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybrid_reversed._alpha_np',
                                                                                                                                          'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybrid_reversed._loss': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybrid_reversed._loss',
                                                                                                                                      'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybrid_reversed._next_q': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybrid_reversed._next_q',
                                                                                                                                        'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybrid_reversed._post_load': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybrid_reversed._post_load',
                                                                                                                                           'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybrid_reversed._update_alpha': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybrid_reversed._update_alpha',
                                                                                                                                              'RL_OM/agents/rl_agents/sac_hybrid_reversed.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_reversed.SAC_hybrid_reversed.fit': ( 'agents/rl_agents/sac_hybrid_reversed.html#sac_hybrid_reversed.fit',
                                                                                                                                    'RL_OM/agents/rl_agents/sac_hybrid_reversed.py')},
            'RL_OM.agents.rl_agents.sac_hybrid_separate': { 'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybridPolicy': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybridpolicy',
                                                                                                                             'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybridPolicy.__call__': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybridpolicy.__call__',
                                                                                                                                      'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybridPolicy.__init__': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybridpolicy.__init__',
                                                                                                                                      'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybridPolicy.compute_action_and_log_prob': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybridpolicy.compute_action_and_log_prob',
                                                                                                                                                         'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybridPolicy.compute_action_and_log_prob_t': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybridpolicy.compute_action_and_log_prob_t',
                                                                                                                                                           'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybridPolicy.cont_distribution': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybridpolicy.cont_distribution',
                                                                                                                                               'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybridPolicy.discrete_distribution': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybridpolicy.discrete_distribution',
                                                                                                                                                   'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybridPolicy.draw_action': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybridpolicy.draw_action',
                                                                                                                                         'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybridPolicy.draw_action_mean_and_logits': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybridpolicy.draw_action_mean_and_logits',
                                                                                                                                                         'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybridPolicy.draw_noisy_action': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybridpolicy.draw_noisy_action',
                                                                                                                                               'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybridPolicy.entropy': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybridpolicy.entropy',
                                                                                                                                     'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybridPolicy.get_weights': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybridpolicy.get_weights',
                                                                                                                                         'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybridPolicy.parameters': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybridpolicy.parameters',
                                                                                                                                        'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybridPolicy.reset': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybridpolicy.reset',
                                                                                                                                   'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybridPolicy.set_weights': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybridpolicy.set_weights',
                                                                                                                                         'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybridPolicy.use_cuda': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybridpolicy.use_cuda',
                                                                                                                                      'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybrid_separate': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybrid_separate',
                                                                                                                                'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybrid_separate.__init__': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybrid_separate.__init__',
                                                                                                                                         'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybrid_separate._alpha': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybrid_separate._alpha',
                                                                                                                                       'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybrid_separate._alpha_np': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybrid_separate._alpha_np',
                                                                                                                                          'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybrid_separate._loss': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybrid_separate._loss',
                                                                                                                                      'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybrid_separate._next_q': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybrid_separate._next_q',
                                                                                                                                        'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybrid_separate._post_load': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybrid_separate._post_load',
                                                                                                                                           'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybrid_separate._update_alpha': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybrid_separate._update_alpha',
                                                                                                                                              'RL_OM/agents/rl_agents/sac_hybrid_separate.py'),
                                                            'RL_OM.agents.rl_agents.sac_hybrid_separate.SAC_hybrid_separate.fit': ( 'agents/rl_agents/sac_hybrid_separate.html#sac_hybrid_separate.fit',
                                                                                                                                    'RL_OM/agents/rl_agents/sac_hybrid_separate.py')},
            'RL_OM.core': {'RL_OM.core.foo': ('core.html#foo', 'RL_OM/core.py')},
            'RL_OM.environments.calculation_functions': { 'RL_OM.environments.calculation_functions.eoq_qr_calculations_qr_action': ( 'environments/calculation_functions.html#eoq_qr_calculations_qr_action',
                                                                                                                                      'RL_OM/environments/calculation_functions.py'),
                                                          'RL_OM.environments.calculation_functions.eoq_qr_calculations_single_action': ( 'environments/calculation_functions.html#eoq_qr_calculations_single_action',
                                                                                                                                          'RL_OM/environments/calculation_functions.py'),
                                                          'RL_OM.environments.calculation_functions.get_fixed_ordering_cost': ( 'environments/calculation_functions.html#get_fixed_ordering_cost',
                                                                                                                                'RL_OM/environments/calculation_functions.py'),
                                                          'RL_OM.environments.calculation_functions.get_orders_arriving_stochastic': ( 'environments/calculation_functions.html#get_orders_arriving_stochastic',
                                                                                                                                       'RL_OM/environments/calculation_functions.py'),
                                                          'RL_OM.environments.calculation_functions.mpfc_calculations_ss_action': ( 'environments/calculation_functions.html#mpfc_calculations_ss_action',
                                                                                                                                    'RL_OM/environments/calculation_functions.py'),
                                                          'RL_OM.environments.calculation_functions.normalize_reward_FC': ( 'environments/calculation_functions.html#normalize_reward_fc',
                                                                                                                            'RL_OM/environments/calculation_functions.py'),
                                                          'RL_OM.environments.calculation_functions.normalize_reward_NV': ( 'environments/calculation_functions.html#normalize_reward_nv',
                                                                                                                            'RL_OM/environments/calculation_functions.py'),
                                                          'RL_OM.environments.calculation_functions.nv_calculations': ( 'environments/calculation_functions.html#nv_calculations',
                                                                                                                        'RL_OM/environments/calculation_functions.py')},
            'RL_OM.environments.data_generators': { 'RL_OM.environments.data_generators.make_ARMA': ( 'environments/data_generators.html#make_arma',
                                                                                                      'RL_OM/environments/data_generators.py'),
                                                    'RL_OM.environments.data_generators.make_ARMA_features': ( 'environments/data_generators.html#make_arma_features',
                                                                                                               'RL_OM/environments/data_generators.py'),
                                                    'RL_OM.environments.data_generators.make_binary': ( 'environments/data_generators.html#make_binary',
                                                                                                        'RL_OM/environments/data_generators.py'),
                                                    'RL_OM.environments.data_generators.make_continuous_iid': ( 'environments/data_generators.html#make_continuous_iid',
                                                                                                                'RL_OM/environments/data_generators.py'),
                                                    'RL_OM.environments.data_generators.make_regular_binary': ( 'environments/data_generators.html#make_regular_binary',
                                                                                                                'RL_OM/environments/data_generators.py')},
            'RL_OM.environments.feature_converters': { 'RL_OM.environments.feature_converters.feature_oracle': ( 'environments/feature_converters.html#feature_oracle',
                                                                                                                 'RL_OM/environments/feature_converters.py'),
                                                       'RL_OM.environments.feature_converters.get_time_series_features': ( 'environments/feature_converters.html#get_time_series_features',
                                                                                                                           'RL_OM/environments/feature_converters.py')},
            'RL_OM.environments.multi_period_inventory': { 'RL_OM.environments.multi_period_inventory.MultiPeriodEnv': ( 'environments/multi_period_inventory.html#multiperiodenv',
                                                                                                                         'RL_OM/environments/multi_period_inventory.py'),
                                                           'RL_OM.environments.multi_period_inventory.MultiPeriodEnv.__init__': ( 'environments/multi_period_inventory.html#multiperiodenv.__init__',
                                                                                                                                  'RL_OM/environments/multi_period_inventory.py'),
                                                           'RL_OM.environments.multi_period_inventory.MultiPeriodEnv.convert_to_numpy_array': ( 'environments/multi_period_inventory.html#multiperiodenv.convert_to_numpy_array',
                                                                                                                                                'RL_OM/environments/multi_period_inventory.py'),
                                                           'RL_OM.environments.multi_period_inventory.MultiPeriodEnv.render': ( 'environments/multi_period_inventory.html#multiperiodenv.render',
                                                                                                                                'RL_OM/environments/multi_period_inventory.py'),
                                                           'RL_OM.environments.multi_period_inventory.MultiPeriodEnv.reset': ( 'environments/multi_period_inventory.html#multiperiodenv.reset',
                                                                                                                               'RL_OM/environments/multi_period_inventory.py'),
                                                           'RL_OM.environments.multi_period_inventory.MultiPeriodEnv.set_observation_space': ( 'environments/multi_period_inventory.html#multiperiodenv.set_observation_space',
                                                                                                                                               'RL_OM/environments/multi_period_inventory.py'),
                                                           'RL_OM.environments.multi_period_inventory.MultiPeriodEnv.set_observation_state': ( 'environments/multi_period_inventory.html#multiperiodenv.set_observation_state',
                                                                                                                                               'RL_OM/environments/multi_period_inventory.py'),
                                                           'RL_OM.environments.multi_period_inventory.MultiPeriodEnv.step': ( 'environments/multi_period_inventory.html#multiperiodenv.step',
                                                                                                                              'RL_OM/environments/multi_period_inventory.py'),
                                                           'RL_OM.environments.multi_period_inventory.MultiPeriodEnvMP': ( 'environments/multi_period_inventory.html#multiperiodenvmp',
                                                                                                                           'RL_OM/environments/multi_period_inventory.py'),
                                                           'RL_OM.environments.multi_period_inventory.MultiPeriodEnvMP.__init__': ( 'environments/multi_period_inventory.html#multiperiodenvmp.__init__',
                                                                                                                                    'RL_OM/environments/multi_period_inventory.py'),
                                                           'RL_OM.environments.multi_period_inventory.MultiPeriodEnvMP.convert_to_numpy_array': ( 'environments/multi_period_inventory.html#multiperiodenvmp.convert_to_numpy_array',
                                                                                                                                                  'RL_OM/environments/multi_period_inventory.py'),
                                                           'RL_OM.environments.multi_period_inventory.MultiPeriodEnvMP.render': ( 'environments/multi_period_inventory.html#multiperiodenvmp.render',
                                                                                                                                  'RL_OM/environments/multi_period_inventory.py'),
                                                           'RL_OM.environments.multi_period_inventory.MultiPeriodEnvMP.reset': ( 'environments/multi_period_inventory.html#multiperiodenvmp.reset',
                                                                                                                                 'RL_OM/environments/multi_period_inventory.py'),
                                                           'RL_OM.environments.multi_period_inventory.MultiPeriodEnvMP.set_observation_space': ( 'environments/multi_period_inventory.html#multiperiodenvmp.set_observation_space',
                                                                                                                                                 'RL_OM/environments/multi_period_inventory.py'),
                                                           'RL_OM.environments.multi_period_inventory.MultiPeriodEnvMP.set_observation_state': ( 'environments/multi_period_inventory.html#multiperiodenvmp.set_observation_state',
                                                                                                                                                 'RL_OM/environments/multi_period_inventory.py'),
                                                           'RL_OM.environments.multi_period_inventory.MultiPeriodEnvMP.step': ( 'environments/multi_period_inventory.html#multiperiodenvmp.step',
                                                                                                                                'RL_OM/environments/multi_period_inventory.py')},
            'RL_OM.experiment_functions.run_experiment': { 'RL_OM.experiment_functions.run_experiment.check_val_test': ( 'experiment_functions/run_experiment.html#check_val_test',
                                                                                                                         'RL_OM/experiment_functions/run_experiment.py'),
                                                           'RL_OM.experiment_functions.run_experiment.experiment_stepwise': ( 'experiment_functions/run_experiment.html#experiment_stepwise',
                                                                                                                              'RL_OM/experiment_functions/run_experiment.py'),
                                                           'RL_OM.experiment_functions.run_experiment.experiment_stepwise_no_log': ( 'experiment_functions/run_experiment.html#experiment_stepwise_no_log',
                                                                                                                                     'RL_OM/experiment_functions/run_experiment.py'),
                                                           'RL_OM.experiment_functions.run_experiment.experiment_wandb': ( 'experiment_functions/run_experiment.html#experiment_wandb',
                                                                                                                           'RL_OM/experiment_functions/run_experiment.py'),
                                                           'RL_OM.experiment_functions.run_experiment.experiment_wandb_optimize': ( 'experiment_functions/run_experiment.html#experiment_wandb_optimize',
                                                                                                                                    'RL_OM/experiment_functions/run_experiment.py'),
                                                           'RL_OM.experiment_functions.run_experiment.load_networks': ( 'experiment_functions/run_experiment.html#load_networks',
                                                                                                                        'RL_OM/experiment_functions/run_experiment.py'),
                                                           'RL_OM.experiment_functions.run_experiment.save_networks': ( 'experiment_functions/run_experiment.html#save_networks',
                                                                                                                        'RL_OM/experiment_functions/run_experiment.py'),
                                                           'RL_OM.experiment_functions.run_experiment.test_agent': ( 'experiment_functions/run_experiment.html#test_agent',
                                                                                                                     'RL_OM/experiment_functions/run_experiment.py')},
            'RL_OM.utils': { 'RL_OM.utils.combine_dict': ('utils/utils.html#combine_dict', 'RL_OM/utils.py'),
                             'RL_OM.utils.convert_str_none_to_none': ('utils/utils.html#convert_str_none_to_none', 'RL_OM/utils.py'),
                             'RL_OM.utils.create_env_agent': ('utils/utils.html#create_env_agent', 'RL_OM/utils.py'),
                             'RL_OM.utils.delete_lag_window_from_config': ( 'utils/utils.html#delete_lag_window_from_config',
                                                                            'RL_OM/utils.py'),
                             'RL_OM.utils.get_actions_per_product': ('utils/utils.html#get_actions_per_product', 'RL_OM/utils.py'),
                             'RL_OM.utils.get_git_revision_hash': ('utils/utils.html#get_git_revision_hash', 'RL_OM/utils.py'),
                             'RL_OM.utils.get_version': ('utils/utils.html#get_version', 'RL_OM/utils.py'),
                             'RL_OM.utils.init_pipeline': ('utils/utils.html#init_pipeline', 'RL_OM/utils.py'),
                             'RL_OM.utils.load_agent_function': ('utils/utils.html#load_agent_function', 'RL_OM/utils.py'),
                             'RL_OM.utils.merge_with_namespace': ('utils/utils.html#merge_with_namespace', 'RL_OM/utils.py'),
                             'RL_OM.utils.prepare_calculation_function': ( 'utils/utils.html#prepare_calculation_function',
                                                                           'RL_OM/utils.py'),
                             'RL_OM.utils.prepare_hyperparameter_opt': ('utils/utils.html#prepare_hyperparameter_opt', 'RL_OM/utils.py'),
                             'RL_OM.utils.prepare_lag_window': ('utils/utils.html#prepare_lag_window', 'RL_OM/utils.py'),
                             'RL_OM.utils.track_normalization': ('utils/utils.html#track_normalization', 'RL_OM/utils.py')}}}
